% Auto-generated chapter 3 for muslim
% Hadiths in this chapter: 157

\hadithdefcmd{muslim}{679}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ إِحْدَانَا إِذَا كَانَتْ حَائِضًا أَمَرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَأْتَزِرُ بِإِزَارٍ ثُمَّ يُبَاشِرُهَا ‏.‏\hadithno{679}\hadithtrans{A'isha reported:When anyone amongst us (amongst the wives of the Holy Prophet) menstruated, the Messenger of Allah (ﷺ) asked her to tie a waist-wrapper over her (body) and then embraced her}}
\hadithdefcmd{muslim}{680}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، ح وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، أَخْبَرَنَا أَبُو إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ إِحْدَانَا إِذَا كَانَتْ حَائِضًا أَمَرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَأْتَزِرَ فِي فَوْرِ حَيْضَتِهَا ثُمَّ يُبَاشِرُهَا ‏.‏ قَالَتْ وَأَيُّكُمْ يَمْلِكُ إِرْبَهُ كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْلِكُ إِرْبَهُ ‏.‏\hadithno{680}\hadithtrans{A'isha reported:When anyone amongst us was menstruating the Messenger of Allah (ﷺ) asked her to tie waist-wrapper daring the time when the menstrual blood profusely flowed and then embraced her; and she ('A'isha) observed: And who amongst you can have control over his desires as the Messenger of Allah (ﷺ) had over his desires}}
\hadithdefcmd{muslim}{681}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنِ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنْ مَيْمُونَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُبَاشِرُ نِسَاءَهُ فَوْقَ الإِزَارِ وَهُنَّ حُيَّضٌ ‏.‏\hadithno{681}\hadithtrans{Maimuna (the wife of the Holy Prophet) reported:The Messenger of Allah (ﷺ) contacted and embraced his wives over the waist-wrapper when they were menstruating}}
\hadithdefcmd{muslim}{682}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ مَخْرَمَةَ، ح وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ قَالَ سَمِعْتُ مَيْمُونَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضْطَجِعُ مَعِي وَأَنَا حَائِضٌ وَبَيْنِي وَبَيْنَهُ ثَوْبٌ ‏.‏\hadithno{682}\hadithtrans{Kuraibthe freed slave of Ibn Abbas, reported:I heard it from Maimuna, the wife of the Messenger of Allah (way peace be upon him): The Messenger of Allah (ﷺ) used to lie with me when I menstruated, and there was a cloth between me and him}}
\hadithdefcmd{muslim}{683}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ زَيْنَبَ بِنْتَ أُمِّ سَلَمَةَ، حَدَّثَتْهُ أَنَّ أُمَّ سَلَمَةَ حَدَّثَتْهَا قَالَتْ، بَيْنَمَا أَنَا مُضْطَجِعَةٌ، مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْخَمِيلَةِ إِذْ حِضْتُ فَانْسَلَلْتُ فَأَخَذْتُ ثِيَابَ حَيْضَتِي فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنُفِسْتِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ فَدَعَانِي فَاضْطَجَعْتُ مَعَهُ فِي الْخَمِيلَةِ ‏.‏ قَالَتْ وَكَانَتْ هِيَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَغْتَسِلاَنِ فِي الإِنَاءِ الْوَاحِدِ مِنَ الْجَنَابَةِ ‏.‏\hadithno{683}\hadithtrans{Umm Salama reported:While I was lying with the Messenger of Allah (ﷺ) in a bed cover I menstruated, so I slipped away and I took up the clothes (which I wore) in menses. Upon this the Messenger of Allah (ﷺ) said: Have you menstruated? I said: Yes. He called me and I lay down}}
\hadithdefcmd{muslim}{684}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا اعْتَكَفَ يُدْنِي إِلَىَّ رَأْسَهُ فَأُرَجِّلُهُ وَكَانَ لاَ يَدْخُلُ الْبَيْتَ إِلاَّ لِحَاجَةِ الإِنْسَانِ ‏.‏\hadithno{684}\hadithtrans{It is reported from 'A'isha that she observed:When the Messenger of Allah (ﷺ) was in I'tikaf, he inclined his head towards me and I combedhis hair, and he did not enter the house but for the natural calls (for relieving himself)}}
\hadithdefcmd{muslim}{685}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، قَالَ أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ إِنْ كُنْتُ لأَدْخُلُ الْبَيْتَ لِلْحَاجَةِ وَالْمَرِيضُ فِيهِ فَمَا أَسْأَلُ عَنْهُ إِلاَّ وَأَنَا مَارَّةٌ وَإِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُدْخِلُ عَلَىَّ رَأْسَهُ وَهُوَ فِي الْمَسْجِدِ فَأُرَجِّلُهُ وَكَانَ لاَ يَدْخُلُ الْبَيْتَ إِلاَّ لِحَاجَةٍ إِذَا كَانَ مُعْتَكِفًا ‏.‏ وَقَالَ ابْنُ رُمْحٍ إِذَا كَانُوا مُعْتَكِفِينَ ‏.‏\hadithno{685}\hadithtrans{Amra daughter of 'Abd al-Rahman reported:'A'isha, wife of the Messenger of Allah (ﷺ) observed: When I was (in I'tikaf), I entered the house for the call of nature, and while passing I inquired after the health of the sick (in the. family), and when the Messenger of Allah (ﷺ) was (in I'tikaf), he put out his head towards me, while he himself was in the mosque, and I combed his hair; and he did not enter the house except for the call of nature so long as he was In I'tikaf; and Ibn Rumh stated: As long as they (the Prophet and his wives) were among the observers of I'tikaf}}
\hadithdefcmd{muslim}{686}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُخْرِجُ إِلَىَّ رَأْسَهُ مِنَ الْمَسْجِدِ وَهُوَ مُجَاوِرٌ فَأَغْسِلُهُ وَأَنَا حَائِضٌ ‏.‏\hadithno{686}\hadithtrans{A'isha, the wife of the Apostle (may peace he upon him), reported:The Messenger of Allah (ﷺ) put out from the mosque his head for me as he was in I'tikaf, and I washed it in the state that I was menstruating}}
\hadithdefcmd{muslim}{687}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ هِشَامٍ، أَخْبَرَنَا عُرْوَةُ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُدْنِي إِلَىَّ رَأْسَهُ وَأَنَا فِي حُجْرَتِي فَأُرَجِّلُ رَأْسَهُ وَأَنَا حَائِضٌ ‏.‏\hadithno{687}\hadithtrans{Urwa reported it from 'A'isha that she observed:The Messenger of Allah (ﷺ) inclined his head towards me (from the mosque) while I was in my apartment and I combed it in a state of menstruation}}
\hadithdefcmd{muslim}{688}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْسِلُ رَأْسَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا حَائِضٌ ‏.‏\hadithno{688}\hadithtrans{Al-Aswad narrated it from 'A'isha that she observed:I used to wash the head of the Messenger of Allah (ﷺ), while I was in a state of menstruation}}
\hadithdefcmd{muslim}{689}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ ثَابِتِ بْنِ عُبَيْدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَاوِلِينِي الْخُمْرَةَ مِنَ الْمَسْجِدِ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ إِنِّي حَائِضٌ ‏.‏ فَقَالَ ‏"‏ إِنَّ حَيْضَتَكِ لَيْسَتْ فِي يَدِكِ ‏"‏ ‏.‏\hadithno{689}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) said to me: Get me the mat from the mosque. I said: I am menstruating. Upon this he remarked: Your menstruation is not in your hand}}
\hadithdefcmd{muslim}{690}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ حَجَّاجٍ، وَابْنِ أَبِي غَنِيَّةَ، عَنْ ثَابِتِ بْنِ عُبَيْدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أُنَاوِلَهُ الْخُمْرَةَ مِنَ الْمَسْجِدِ ‏.‏ فَقُلْتُ إِنِّي حَائِضٌ ‏.‏ فَقَالَ ‏ "‏ تَنَاوَلِيهَا فَإِنَّ الْحَيْضَةَ لَيْسَتْ فِي يَدِكِ ‏"‏ ‏.‏\hadithno{690}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) ordered me that I should get him the mat from the mosque. I said: I am menstruating. He (the Holy Prophet) said: Do get me that, for menstruation is not in your hand}}
\hadithdefcmd{muslim}{691}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كَامِلٍ وَمُحَمَّدُ بْنُ حَاتِمٍ كُلُّهُمْ عَنْ يَحْيَى بْنِ سَعِيدٍ، - قَالَ زُهَيْرٌ حَدَّثَنَا يَحْيَى، - عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ فَقَالَ ‏"‏ يَا عَائِشَةُ نَاوِلِينِي الثَّوْبَ ‏"‏ ‏.‏ فَقَالَتْ إِنِّي حَائِضٌ ‏.‏ فَقَالَ ‏"‏ إِنَّ حَيْضَتَكِ لَيْسَتْ فِي يَدِكِ ‏"‏ فَنَاوَلَتْهُ ‏.‏\hadithno{691}\hadithtrans{Abu Huraira reported:While the Messenger of Allah (ﷺ) was in the mosque, he said: O 'A'isha, get me that garment. She said: I am menstruating. Upon this he remarked: Your menstruation is not in your hand, and she, therefore, got him that}}
\hadithdefcmd{muslim}{692}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، وَسُفْيَانَ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَشْرَبُ وَأَنَا حَائِضٌ، ثُمَّ أُنَاوِلُهُ النَّبِيَّ صلى الله عليه وسلم فَيَضَعُ فَاهُ عَلَى مَوْضِعِ فِيَّ فَيَشْرَبُ وَأَتَعَرَّقُ الْعَرْقَ وَأَنَا حَائِضٌ ثُمَّ أُنَاوِلُهُ النَّبِيَّ صلى الله عليه وسلم فَيَضَعُ فَاهُ عَلَى مَوْضِعِ فِيَّ ‏.‏ وَلَمْ يَذْكُرْ زُهَيْرٌ فَيَشْرَبُ ‏.‏\hadithno{692}\hadithtrans{A'isha reported:I would drink when I was menstruating, then I would hand it (the vessel) to the Apostle (ﷺ) and he would put his mouth where mine had been, and drink, and I would eat flesh from a bone when I was menstruating, then hand it over to the Apostle (ﷺ) and he would put his mouth where mine had been. Zuhair made no mention of (the Holy Prophet's) drinking}}
\hadithdefcmd{muslim}{693}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَكِّيُّ، عَنْ مَنْصُورٍ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَّكِئُ فِي حِجْرِي وَأَنَا حَائِضٌ فَيَقْرَأُ الْقُرْآنَ ‏.‏\hadithno{693}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) would recline in my lap when I was menstruating, and recite the Qur'an}}
\hadithdefcmd{muslim}{694}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ الْيَهُودَ، كَانُوا إِذَا حَاضَتِ الْمَرْأَةُ فِيهِمْ لَمْ يُؤَاكِلُوهَا وَلَمْ يُجَامِعُوهُنَّ فِي الْبُيُوتِ فَسَأَلَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم النَّبِيَّ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏ وَيَسْأَلُونَكَ عَنِ الْمَحِيضِ قُلْ هُوَ أَذًى فَاعْتَزِلُوا النِّسَاءَ فِي الْمَحِيضِ‏\}‏ إِلَى آخِرِ الآيَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اصْنَعُوا كُلَّ شَىْءٍ إِلاَّ النِّكَاحَ ‏"‏ ‏.‏ فَبَلَغَ ذَلِكَ الْيَهُودَ فَقَالُوا مَا يُرِيدُ هَذَا الرَّجُلُ أَنْ يَدَعَ مِنْ أَمْرِنَا شَيْئًا إِلاَّ خَالَفَنَا فِيهِ فَجَاءَ أُسَيْدُ بْنُ حُضَيْرٍ وَعَبَّادُ بْنُ بِشْرٍ فَقَالاَ يَا رَسُولَ اللَّهِ إِنَّ الْيَهُودَ تَقُولُ كَذَا وَكَذَا ‏.‏ فَلاَ نُجَامِعُهُنَّ فَتَغَيَّرَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى ظَنَنَّا أَنْ قَدْ وَجَدَ عَلَيْهِمَا فَخَرَجَا فَاسْتَقْبَلَهُمَا هَدِيَّةٌ مِنْ لَبَنٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَرْسَلَ فِي آثَارِهِمَا فَسَقَاهُمَا فَعَرَفَا أَنْ لَمْ يَجِدْ عَلَيْهِمَا ‏.‏\hadithno{694}\hadithtrans{Thabit narrated it from Anas:Among the Jews, when a woman menstruated, they did not dine with her, nor did they live with them in their houses; so the Companions of the Apostle (ﷺ) asked The Apostle (ﷺ), and Allah, the Exalted revealed:" And they ask you about menstruation; say it is a pollution, so keep away from woman during menstruation" to the end (Qur'an, ii. 222). The Messenger of Allah (ﷺ) said: Do everything except intercourse. The Jews heard of that and said: This man does not want to leave anything we do without opposing us in it. Usaid b. Hudair and Abbad b. Bishr came and said: Messenger of Allah, the Jews say such and such thing. We should not have, therefore, any contactwith them (as the Jews do). The face of the Messenger of Allah (way peace be upon him) underwent such a change that we thought he was angry with them, but when they went out, they happened to receive a gift of milk which was sent to the Messenger of Allah (ﷺ). He (the Holy Prophet) called for them and gave them drink, whereby they knew that he was not angry with them}}
\hadithdefcmd{muslim}{695}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، وَأَبُو مُعَاوِيَةَ وَهُشَيْمٌ عَنِ الأَعْمَشِ، عَنْ مُنْذِرِ بْنِ يَعْلَى، - وَيُكْنَى أَبَا يَعْلَى - عَنِ ابْنِ الْحَنَفِيَّةِ، عَنْ عَلِيٍّ، قَالَ كُنْتُ رَجُلاً مَذَّاءً وَكُنْتُ أَسْتَحْيِي أَنْ أَسْأَلَ النَّبِيَّ صلى الله عليه وسلم لِمَكَانِ ابْنَتِهِ فَأَمَرْتُ الْمِقْدَادَ بْنَ الأَسْوَدِ فَسَأَلَهُ فَقَالَ ‏ "‏ يَغْسِلُ ذَكَرَهُ وَيَتَوَضَّأُ ‏"‏ ‏.‏\hadithno{695}\hadithtrans{Ali reported:I was one whose prostatic fluid flowed readily and I was ashamed to ask the Apostle (ﷺ) about it, because of the position of his daughter. I, therefore, asked Miqdad. b. al-Asad and he inquired of him (the Holy Prophet). He (the Holy Prophet) said: He should wash his male organ and perform ablution}}
\hadithdefcmd{muslim}{696}{وَحَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي سُلَيْمَانُ، قَالَ سَمِعْتُ مُنْذِرًا، عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ عَلِيٍّ، أَنَّهُ قَالَ اسْتَحْيَيْتُ أَنْ أَسْأَلَ، النَّبِيَّ صلى الله عليه وسلم عَنِ الْمَذْىِ مِنْ أَجْلِ فَاطِمَةَ فَأَمَرْتُ الْمِقْدَادَ فَسَأَلَهُ فَقَالَ ‏ "‏ مِنْهُ الْوُضُوءُ ‏"‏ ‏.‏\hadithno{696}\hadithtrans{Ali reported:I felt shy of asking about prostatic fluid from the Apostle (ﷺ) because of Fatimah. I, therefore, asked al-Miqdad (to ask on my behalf) and he asked. He (the Holy Prophet) said: Ablution is obligatory in such a case}}
\hadithdefcmd{muslim}{697}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ عَلِيُّ بْنُ أَبِي طَالِبٍ أَرْسَلْنَا الْمِقْدَادَ بْنَ الأَسْوَدِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ عَنِ الْمَذْىِ يَخْرُجُ مِنَ الإِنْسَانِ كَيْفَ يَفْعَلُ بِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَوَضَّأْ وَانْضَحْ فَرْجَكَ ‏"‏ ‏.‏\hadithno{697}\hadithtrans{Ibn 'Abbas reported it from 'Ali:We sent al-Miqdad b. al-Aswad to the Messenger of Allah (ﷺ) to ask him what must be done about prostatic fluid which flows from (the private part of) a person. The Messenger of Allah (ﷺ) said: Perform ablution and wash your sexual organ}}
\hadithdefcmd{muslim}{698}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَامَ مِنَ اللَّيْلِ فَقَضَى حَاجَتَهُ ثُمَّ غَسَلَ وَجْهَهُ وَيَدَيْهِ ثُمَّ نَامَ ‏.‏\hadithno{698}\hadithtrans{Ibn 'Abbas reported:The Apostle (ﷺ) woke up at night; relieved himself, and then washed his face and hands and then again slept}}
\hadithdefcmd{muslim}{699}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ أَنْ يَنَامَ وَهُوَ جُنُبٌ تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ قَبْلَ أَنْ يَنَامَ ‏.‏\hadithno{699}\hadithtrans{A'isha reported:Whenever the Messenger of Allah (ﷺ) intended to sleep after having sexual intercourse, he performed ablution as for the prayer before going to sleep}}
\hadithdefcmd{muslim}{700}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، وَوَكِيعٌ، وَغُنْدَرٌ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا كَانَ جُنُبًا فَأَرَادَ أَنْ يَأْكُلَ أَوْ يَنَامَ تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ‏.‏\hadithno{700}\hadithtrans{A'isha reported:Whenever the Messenger of Allah (ﷺ) had sexual intercourse and intended to eat or sleep, he performed the ablution of prayer}}
\hadithdefcmd{muslim}{701}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ قَالَ ابْنُ الْمُثَنَّى فِي حَدِيثِهِ حَدَّثَنَا الْحَكَمُ، سَمِعْتُ إِبْرَاهِيمَ، يُحَدِّثُ ‏.‏\hadithno{701}\hadithtrans{This hadith has been transmitted by Shu'ba with the same chain of transmitters. Ibn at-Muthanna said in his narration:AI-Hakam narrated to us who heard from Ibrahim narrating that}}
\hadithdefcmd{muslim}{702}{وَحَدَّثَنِي مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ - وَاللَّفْظُ لَهُمَا - قَالَ ابْنُ نُمَيْرٍ حَدَّثَنَا أَبِي وَقَالَ أَبُو بَكْرٍ، حَدَّثَنَا أَبُو أُسَامَةَ، - قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، قَالَ يَا رَسُولَ اللَّهِ أَيَرْقُدُ أَحَدُنَا وَهُوَ جُنُبٌ قَالَ ‏ "‏ نَعَمْ إِذَا تَوَضَّأَ ‏"‏ ‏.‏\hadithno{702}\hadithtrans{Ibn 'Umar reported:Umar said: Is one amongst us permitted to sleep in a state of impurity (i. e. after having sexual intercourse)? He (the Holy Prophet) said: Yes, after performing ablution}}
\hadithdefcmd{muslim}{703}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، اسْتَفْتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ هَلْ يَنَامُ أَحَدُنَا وَهُوَ جُنُبٌ قَالَ ‏ "‏ نَعَمْ لِيَتَوَضَّأْ ثُمَّ لْيَنَمْ حَتَّى يَغْتَسِلَ إِذَا شَاءَ ‏"‏ ‏.‏\hadithno{703}\hadithtrans{Ibn 'Umar said:'Umar asked the verdict of the Shari'ah from the Apostle (ﷺ) thus: Is it permissible for any one of us to sleep in a state of impurity? He (the Prophet said: Yes, he must perform ablution and then sleep and take a bath when he desires)}}
\hadithdefcmd{muslim}{704}{وَحَدَّثَنِي يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ ذَكَرَ عُمَرُ بْنُ الْخَطَّابِ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ تُصِيبُهُ جَنَابَةٌ مِنَ اللَّيْلِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَوَضَّأْ وَاغْسِلْ ذَكَرَكَ ثُمَّ نَمْ ‏"‏ ‏.‏\hadithno{704}\hadithtrans{Ibn Umar reported:Umar b. al-Khattab said to the Messenger of Allah (ﷺ), that he became Junbi during the night. The Messenger of Allah (ﷺ) said to him: Perform ablution, wash your sexual organ and then go to sleep}}
\hadithdefcmd{muslim}{705}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَيْسٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ وِتْرِ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ الْحَدِيثَ قُلْتُ كَيْفَ كَانَ يَصْنَعُ فِي الْجَنَابَةِ أَكَانَ يَغْتَسِلُ قَبْلَ أَنْ يَنَامَ أَمْ يَنَامُ قَبْلَ أَنْ يَغْتَسِلَ قَالَتْ كُلُّ ذَلِكَ قَدْ كَانَ يَفْعَلُ رُبَّمَا اغْتَسَلَ فَنَامَ وَرُبَّمَا تَوَضَّأَ فَنَامَ ‏.‏ قُلْتُ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي الأَمْرِ سَعَةً ‏.‏\hadithno{705}\hadithtrans{Abdullah b. Abu'l-Qais reported:I asked 'A'isha about the Witr (prayer) of the Messenger of Allah (ﷺ) and made mention of a hadith, then I said: What did he do after having sexual intercourse? Did he take a bath before going to sleep or did he sleep before taking a bath? She said: He did all these. Some- times he took a bath and then slept, and sometimes he performed ablution only and went to sleep. I (the narrator) said: Praise be to Allah Who has made things easy (for human beings)}}
\hadithdefcmd{muslim}{706}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، ح وَحَدَّثَنِيهِ هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، جَمِيعًا عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{706}\hadithtrans{This hadith has been transmitted with the same chain of transmitters from Mu'awyia b. Salih by Zuhair b. Harb, 'Abd al-Rahman b. Mahdi, Harun b. Sa'id al-'Aili and Ibn Wahb}}
\hadithdefcmd{muslim}{707}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، ح وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، كُلُّهُمْ عَنْ عَاصِمٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَتَى أَحَدُكُمْ أَهْلَهُ ثُمَّ أَرَادَ أَنْ يَعُودَ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏ زَادَ أَبُو بَكْرٍ فِي حَدِيثِهِ بَيْنَهُمَا وُضُوءًا وَقَالَ ثُمَّ أَرَادَ أَنْ يُعَاوِدَ ‏.‏\hadithno{707}\hadithtrans{Abu Sa'id al-Khudri reported:The Messenger of Allah (ﷺ) said: When anyone amongst you has sexual intercourse with his wife and then he intends to repeat it, he should perform ablution. In the hadith transmitted by Abu Bakr. (the words are):" Between the two (acts) there should be an ablution," or he (the narrator) said:" Then he intended that it should be repeated}}
\hadithdefcmd{muslim}{708}{وَحَدَّثَنَا الْحَسَنُ بْنُ أَحْمَدَ بْنِ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، حَدَّثَنَا مِسْكِينٌ، - يَعْنِي ابْنَ بُكَيْرٍ الْحَذَّاءَ - عَنْ شُعْبَةَ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَطُوفُ عَلَى نِسَائِهِ بِغُسْلٍ وَاحِدٍ ‏.‏\hadithno{708}\hadithtrans{Anas reported:The Messenger of Allah (ﷺ) used to have sexual intercourse with his wives with a single bath}}
\hadithdefcmd{muslim}{709}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ الْحَنَفِيُّ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، قَالَ قَالَ إِسْحَاقُ بْنُ أَبِي طَلْحَةَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، قَالَ جَاءَتْ أُمُّ سُلَيْمٍ - وَهِيَ جَدَّةُ إِسْحَاقَ - إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ لَهُ وَعَائِشَةُ عِنْدَهُ يَا رَسُولَ اللَّهِ الْمَرْأَةُ تَرَى مَا يَرَى الرَّجُلُ فِي الْمَنَامِ فَتَرَى مِنْ نَفْسِهَا مَا يَرَى الرَّجُلُ مِنْ نَفْسِهِ ‏.‏ فَقَالَتْ عَائِشَةُ يَا أُمَّ سُلَيْمٍ فَضَحْتِ النِّسَاءَ تَرِبَتْ يَمِينُكِ ‏.‏ فَقَالَ لِعَائِشَةَ ‏ "‏ بَلْ أَنْتِ فَتَرِبَتْ يَمِينُكِ نَعَمْ فَلْتَغْتَسِلْ يَا أُمَّ سُلَيْمٍ إِذَا رَأَتْ ذَاكِ ‏"‏ ‏.‏\hadithno{709}\hadithtrans{Anas b. Malik reported:Umm Sulaim who was the grandmother of Ishaq came to the Messenger of Allah (ﷺ) in the presence of 'A'isha and said to him: Messenger of Allah, in case or woman sees what a man sees in dream and she experiences in dream what a man experiences (i. e. experiences orgasm)? Upon this 'A'isha remarked: O Umm Sulaim, you brought humiliation to women;may your right hand be covered with dust. He (the Holy Prophet) said to 'A'isha: Let your hand be covered with dust, and (addressing Umm Sulaim) said: Well, O Umm Sulaim, she should take a bath if she sees that (i. e. she experiences orgasm in dream)}}
\hadithdefcmd{muslim}{710}{حَدَّثَنَا عَبَّاسُ بْنُ الْوَلِيدِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُمْ أَنَّ أُمَّ سُلَيْمٍ حَدَّثَتْ أَنَّهَا، سَأَلَتْ نَبِيَّ اللَّهِ صلى الله عليه وسلم عَنِ الْمَرْأَةِ تَرَى فِي مَنَامِهَا مَا يَرَى الرَّجُلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا رَأَتْ ذَلِكِ الْمَرْأَةُ فَلْتَغْتَسِلْ ‏"‏ ‏.‏ فَقَالَتْ أُمُّ سُلَيْمٍ وَاسْتَحْيَيْتُ مِنْ ذَلِكَ قَالَتْ وَهَلْ يَكُونُ هَذَا فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ فَمِنْ أَيْنَ يَكُونُ الشَّبَهُ إِنَّ مَاءَ الرَّجُلِ غَلِيظٌ أَبْيَضُ وَمَاءَ الْمَرْأَةِ رَقِيقٌ أَصْفَرُ فَمِنْ أَيِّهِمَا عَلاَ أَوْ سَبَقَ يَكُونُ مِنْهُ الشَّبَهُ ‏"‏ ‏.‏\hadithno{710}\hadithtrans{Anas b. Malik reported that Umm Sulaim narrated it that she asked the Messenger of Allah (ﷺ) about a woman who sees in a dream what a man sees (sexual dream). The Messenger of Allah (may peace be upon bi m) said:In case a woman sees that, she must take a bath. Umm Sulaim said: I was bashful on account of that and said: Does it happen? Upon this the Messenger of Allah (ﷺ) said: Yes (it does happen), otherwise how can (a child) resemble her? Man's discharge (i. e. sperm) is thick and white and the discharge of woman is thin and yellow; so the resemblance comes from the one whose genes prevail or dominate}}
\hadithdefcmd{muslim}{711}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا صَالِحُ بْنُ عُمَرَ، حَدَّثَنَا أَبُو مَالِكٍ الأَشْجَعِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَأَلَتِ امْرَأَةٌ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْمَرْأَةِ تَرَى فِي مَنَامِهَا مَا يَرَى الرَّجُلُ فِي مَنَامِهِ فَقَالَ ‏ "‏ إِذَا كَانَ مِنْهَا مَا يَكُونُ مِنَ الرَّجُلِ فَلْتَغْتَسِلْ ‏"‏ ‏.‏\hadithno{711}\hadithtrans{Anas b. Malik reported:A woman asked the Messenger of Allah (way peace be upon him) about a woman who sees in her dream what a man sees in his dream (sexual dream). He (the Holy Prophet) said: If she experiences what a man experiences, she should take a bath}}
\hadithdefcmd{muslim}{712}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ جَاءَتْ أُمُّ سُلَيْمٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ لاَ يَسْتَحْيِي مِنَ الْحَقِّ فَهَلْ عَلَى الْمَرْأَةِ مِنْ غُسْلٍ إِذَا احْتَلَمَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ إِذَا رَأَتِ الْمَاءَ ‏"‏ ‏.‏ فَقَالَتْ أُمُّ سَلَمَةَ يَا رَسُولَ اللَّهِ وَتَحْتَلِمُ الْمَرْأَةُ فَقَالَ ‏"‏ تَرِبَتْ يَدَاكِ فَبِمَ يُشْبِهُهَا وَلَدُهَا ‏"‏ ‏.‏\hadithno{712}\hadithtrans{Umm Salama reported:Umm Sulaim went to the Messenger of Allah (ﷺ) and said: Apostle of Allah, Allah is not ashamed of the truth. Is bathing necessary for a woman when she has a sexual dream? Upon this the Messenger of Allah (ﷺ) said: Yes, when she sees the liquid (vaginal secretion). Umm Salama said: Messenger of Allah, does a woman have sexual dream? He (the Holy Prophet) said: Let your hand be covered with dust, in what way does her child resemble her?}}
\hadithdefcmd{muslim}{713}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، جَمِيعًا عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ مِثْلَ مَعْنَاهُ وَزَادَ قَالَتْ قُلْتُ فَضَحْتِ النِّسَاءَ ‏.‏\hadithno{713}\hadithtrans{This hadith with the same sense (as narrated above) bus been transmitted from Hisham b. 'Urwa with the same chain of narrators but with this addition that she (Umm Salama) said:" You humiliated the women}}
\hadithdefcmd{muslim}{714}{وَحَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ أُمَّ سُلَيْمٍ أُمَّ بَنِي أَبِي طَلْحَةَ دَخَلَتْ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمَعْنَى حَدِيثِ هِشَامٍ غَيْرَ أَنَّ فِيهِ قَالَ قَالَتْ عَائِشَةُ فَقُلْتُ لَهَا أُفٍّ لَكِ أَتَرَى الْمَرْأَةُ ذَلِكِ\hadithno{714}\hadithtrans{A'isha the wife of the Apostle (ﷺ) narrated:Umm Sulaim, the mother of Bani Abu Talha, came to the Messenger of Allah (ﷺ), and a hadith (like that) narrated by Hisham was narrated but for these words. A'isha said: I expressed disapproval to her, saying: Does a woman see a sexual dream?}}
\hadithdefcmd{muslim}{715}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، وَسَهْلُ بْنُ عُثْمَانَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالَ سَهْلٌ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ أَبِيهِ، عَنْ مُصْعَبِ بْنِ شَيْبَةَ، عَنْ مُسَافِعِ بْنِ عَبْدِ اللَّهِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم هَلْ تَغْتَسِلُ الْمَرْأَةُ إِذَا احْتَلَمَتْ وَأَبْصَرَتِ الْمَاءَ فَقَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَقَالَتْ لَهَا عَائِشَةُ تَرِبَتْ يَدَاكِ وَأُلَّتْ ‏.‏ قَالَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ دَعِيهَا وَهَلْ يَكُونُ الشَّبَهُ إِلاَّ مِنْ قِبَلِ ذَلِكِ إِذَا عَلاَ مَاؤُهَا مَاءَ الرَّجُلِ أَشْبَهَ الْوَلَدُ أَخْوَالَهُ وَإِذَا عَلاَ مَاءُ الرَّجُلِ مَاءَهَا أَشْبَهَ أَعْمَامَهُ ‏"‏ ‏.‏\hadithno{715}\hadithtrans{It is reported on the authority of 'A'isha that a woman came to the Messenger of Allah (ﷺ) and inquired:Should a woman wash herself when she sees a sexual dream and sees (the marks) of liquid? He (the Holy Prophet) said: Yes. 'A'isha said to her: May your hand be covered with dust and injured. She narrated: The Messenger of Allah (ﷺ) said: Leave her alone. In what way does the child resemble her but for the fact that when the genes contributed by woman prevail upon those of man, the child resembles the maternal family, and when the genes of man prevail upon those of woman the child resembles the paternal family}}
\hadithdefcmd{muslim}{716}{حَدَّثَنِي الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا أَبُو تَوْبَةَ، - وَهُوَ الرَّبِيعُ بْنُ نَافِعٍ - حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ سَلاَّمٍ - عَنْ زَيْدٍ، - يَعْنِي أَخَاهُ - أَنَّهُ سَمِعَ أَبَا سَلاَّمٍ، قَالَ حَدَّثَنِي أَبُو أَسْمَاءَ الرَّحَبِيُّ، أَنَّ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حَدَّثَهُ قَالَ كُنْتُ قَائِمًا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَ حَبْرٌ مِنْ أَحْبَارِ الْيَهُودِ فَقَالَ السَّلاَمُ عَلَيْكَ يَا مُحَمَّدُ ‏.‏ فَدَفَعْتُهُ دَفْعَةً كَادَ يُصْرَعُ مِنْهَا فَقَالَ لِمَ تَدْفَعُنِي فَقُلْتُ أَلاَ تَقُولُ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ الْيَهُودِيُّ إِنَّمَا نَدْعُوهُ بِاسْمِهِ الَّذِي سَمَّاهُ بِهِ أَهْلُهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اسْمِي مُحَمَّدٌ الَّذِي سَمَّانِي بِهِ أَهْلِي ‏"‏ ‏.‏ فَقَالَ الْيَهُودِيُّ جِئْتُ أَسْأَلُكَ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيَنْفَعُكَ شَىْءٌ إِنْ حَدَّثْتُكَ ‏"‏ ‏.‏ قَالَ أَسْمَعُ بِأُذُنَىَّ فَنَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِعُودٍ مَعَهُ ‏.‏ فَقَالَ ‏"‏ سَلْ ‏"‏ ‏.‏ فَقَالَ الْيَهُودِيُّ أَيْنَ يَكُونُ النَّاسُ يَوْمَ تُبَدَّلُ الأَرْضُ غَيْرَ الأَرْضِ وَالسَّمَوَاتُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُمْ فِي الظُّلْمَةِ دُونَ الْجِسْرِ ‏"‏ ‏.‏ قَالَ فَمَنْ أَوَّلُ النَّاسِ إِجَازَةً قَالَ ‏"‏ فُقَرَاءُ الْمُهَاجِرِينَ ‏"‏ ‏.‏ قَالَ الْيَهُودِيُّ فَمَا تُحْفَتُهُمْ حِينَ يَدْخُلُونَ الْجَنَّةَ قَالَ ‏"‏ زِيَادَةُ كَبِدِ النُّونِ ‏"‏ قَالَ فَمَا غِذَاؤُهُمْ عَلَى إِثْرِهَا قَالَ ‏"‏ يُنْحَرُ لَهُمْ ثَوْرُ الْجَنَّةِ الَّذِي كَانَ يَأْكُلُ مِنْ أَطْرَافِهَا ‏"‏ ‏.‏ قَالَ فَمَا شَرَابُهُمْ عَلَيْهِ قَالَ ‏"‏ مِنْ عَيْنٍ فِيهَا تُسَمَّى سَلْسَبِيلاً ‏"‏ ‏.‏ قَالَ صَدَقْتَ ‏.‏ قَالَ وَجِئْتُ أَسْأَلُكَ عَنْ شَىْءٍ لاَ يَعْلَمُهُ أَحَدٌ مِنْ أَهْلِ الأَرْضِ إِلاَّ نَبِيٌّ أَوْ رَجُلٌ أَوْ رَجُلاَنِ ‏.‏ قَالَ ‏"‏ يَنْفَعُكَ إِنْ حَدَّثْتُكَ ‏"‏ ‏.‏ قَالَ أَسْمَعُ بِأُذُنَىَّ ‏.‏ قَالَ جِئْتُ أَسْأَلُكَ عَنِ الْوَلَدِ قَالَ ‏"‏ مَاءُ الرَّجُلِ أَبْيَضُ وَمَاءُ الْمَرْأَةِ أَصْفَرُ فَإِذَا اجْتَمَعَا فَعَلاَ مَنِيُّ الرَّجُلِ مَنِيَّ الْمَرْأَةِ أَذْكَرَا بِإِذْنِ اللَّهِ وَإِذَا عَلاَ مَنِيُّ الْمَرْأَةِ مَنِيَّ الرَّجُلِ آنَثَا بِإِذْنِ اللَّهِ ‏"‏ ‏.‏ قَالَ الْيَهُودِيُّ لَقَدْ صَدَقْتَ وَإِنَّكَ لَنَبِيٌّ ثُمَّ انْصَرَفَ فَذَهَبَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَقَدْ سَأَلَنِي هَذَا عَنِ الَّذِي سَأَلَنِي عَنْهُ وَمَا لِي عِلْمٌ بِشَىْءٍ مِنْهُ حَتَّى أَتَانِيَ اللَّهُ بِهِ ‏"‏ ‏.‏\hadithno{716}\hadithtrans{Thauban, the freed slave of the Messenger of Allah (ﷺ), said:While I was standing beside the Messenger of Allah (ﷺ) one of the rabbis of the Jews came and said: Peace be upon you, O Muhammad. I pushed him backwith a push that he was going to fall. Upon this he said: Why do you push me? I said: Why don't you say: O Messenger of Allah? The Jew said: We call him by the name by which he was named by his family. The Messenger of Allah (ﷺ) said: My name is Muhammad with which I was named by my family. The Jew said: I have come to ask you (something). The Messenger of Allah (ﷺ) said: Should that thing be of any benefit to you, if I tell you that? He (the Jew) said: I will lend my ears to it. The Messenger of Allah (ﷺ) drew a line with the help of the stick that he had with him and then said: Ask (whatever you like). Thereupon the Jew said: Where would the human beings be on the Daywhen the earth would change into another earth and the heavens too (would change into other heavens)? The Messenger of Allah (ﷺ) said: They would be in darkness beside the Bridge. He (the Jew) again said: Who amongst people would be the first to cross (this bridge).? He said: They would be the poor amongst the refugees. The Jew said: What would constitute their breakfast when they would enter Paradise? He (the Holy Prophet) replied: A caul of the fish-liver. He (the Jew) said. What would be their food alter this? He (the Holy Prophet) said: A bullockwhich was fed in the different quarters of Paradise would be slaughtered for them. He (the Jew) said: What would be their drink? He (the Holy Prophet) said: They would be given drink from the fountain which is named" Salsabil". He (the Jew) said: I have come to ask you about a thing which no one amongst the people on the earth knows except an apostle or one or two men besides him. He (the Holy Prophet) said: Would it benefit you if I tell you that? He (the Jew) said: I would lend ears to that. He then said: I have come to ask you about the child. He (the Holy Prophet) said: The reproductive substance of man is white and that of woman (i. e. ovum central portion) yellow, and when they have sexual intercourse and the male's substance (chromosomes and genes) prevails upon the female's substance (chromosomes and genes), it is the male child that is created by Allah's Decree, and when the substance of the female prevails upon the substance contributed by the male, a female child is formed by the Decree of Allah. The Jew said: What you have said is true; verily you are an Apostle. He then returned and went away. The Messenger of Allah (ﷺ) said: He asked me about such and such things of which I have had no knowledge till Allah gave me that}}
\hadithdefcmd{muslim}{717}{وَحَدَّثَنِيهِ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ سَلاَّمٍ، فِي هَذَا الإِسْنَادِ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ كُنْتُ قَاعِدًا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَالَ زَائِدَةُ كَبِدِ النُّونِ ‏.‏ وَقَالَ أَذْكَرَ وَآنَثَ ‏.‏ وَلَمْ يَقُلْ أَذْكَرَا وَآنَثَا ‏.‏\hadithno{717}\hadithtrans{This tradition has been narrated by Mu'awyia b. Salim with the same chain of transmitters except for the words:I was sitting beside the Messenger of Allah" and some other minor alterations}}
\hadithdefcmd{muslim}{718}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ يَبْدَأُ فَيَغْسِلُ يَدَيْهِ ثُمَّ يُفْرِغُ بِيَمِينِهِ عَلَى شِمَالِهِ فَيَغْسِلُ فَرْجَهُ ثُمَّ يَتَوَضَّأُ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ يَأْخُذُ الْمَاءَ فَيُدْخِلُ أَصَابِعَهُ فِي أُصُولِ الشَّعْرِ حَتَّى إِذَا رَأَى أَنْ قَدِ اسْتَبْرَأَ حَفَنَ عَلَى رَأْسِهِ ثَلاَثَ حَفَنَاتٍ ثُمَّ أَفَاضَ عَلَى سَائِرِ جَسَدِهِ ثُمَّ غَسَلَ رِجْلَيْهِ ‏.‏\hadithno{718}\hadithtrans{A'isha reported:When Allah's Messenger (ﷺ) bathed because of sexual intercourse, he first washed his hands: he then poured water with his right hand on his left hand and washed his private parts. He then performed ablution as is done for prayer'. He then took some water and put his fingers and moved them through the roots of his hair. And when he found that these had been properly mois- tened, then poured three handfuls on his head and then poured water over his body and subsequently washed his feet}}
\hadithdefcmd{muslim}{719}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، كُلُّهُمْ عَنْ هِشَامٍ، فِي هَذَا الإِسْنَادِ وَلَيْسَ فِي حَدِيثِهِمْ غَسْلُ الرِّجْلَيْنِ ‏.‏\hadithno{719}\hadithtrans{This hadith is narrated by Abu Kuraib. Ibn Numair and others, all on the authority of Hisham with the same chain of transmitters, but in their narration these words are not there:" washed his feet}}
\hadithdefcmd{muslim}{720}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اغْتَسَلَ مِنَ الْجَنَابَةِ فَبَدَأَ فَغَسَلَ كَفَّيْهِ ثَلاَثًا ثُمَّ ذَكَرَ نَحْوَ حَدِيثِ أَبِي مُعَاوِيَةَ وَلَمْ يَذْكُرْ غَسْلَ الرِّجْلَيْنِ ‏.‏\hadithno{720}\hadithtrans{Hisham narrated it from his father, who narrated it on the authority of 'A'isha that when the Apostle (ﷺ) took a bath because of sexual inter-course, he first washed the palms of his hands three times, and then the whole hadith was transmitted like that based on the authority of Abu Mu'awyia, but no mention is made of the washing of feet}}
\hadithdefcmd{muslim}{721}{وَحَدَّثَنَاهُ عَمْرٌو النَّاقِدُ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا زَائِدَةُ، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي عُرْوَةُ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ بَدَأَ فَغَسَلَ يَدَيْهِ قَبْلَ أَنْ يُدْخِلَ يَدَهُ فِي الإِنَاءِ ثُمَّ تَوَضَّأَ مِثْلَ وُضُوئِهِ لِلصَّلاَةِ ‏.‏\hadithno{721}\hadithtrans{Urwa has narrated it on the authority of 'A'isha that when Allah's Messenger (ﷺ) took a bath because of sexual intercourse, he first washed his hands before dipping one of them into the basin, and then performed ablu- tion as is done for prayer}}
\hadithdefcmd{muslim}{722}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنِي عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حَدَّثَتْنِي خَالَتِي، مَيْمُونَةُ قَالَتْ أَدْنَيْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم غُسْلَهُ مِنَ الْجَنَابَةِ فَغَسَلَ كَفَّيْهِ مَرَّتَيْنِ أَوْ ثَلاَثًا ثُمَّ أَدْخَلَ يَدَهُ فِي الإِنَاءِ ثُمَّ أَفْرَغَ بِهِ عَلَى فَرْجِهِ وَغَسَلَهُ بِشِمَالِهِ ثُمَّ ضَرَبَ بِشِمَالِهِ الأَرْضَ فَدَلَكَهَا دَلْكًا شَدِيدًا ثُمَّ تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ أَفْرَغَ عَلَى رَأْسِهِ ثَلاَثَ حَفَنَاتٍ مِلْءَ كَفِّهِ ثُمَّ غَسَلَ سَائِرَ جَسَدِهِ ثُمَّ تَنَحَّى عَنْ مَقَامِهِ ذَلِكَ فَغَسَلَ رِجْلَيْهِ ثُمَّ أَتَيْتُهُ بِالْمِنْدِيلِ فَرَدَّهُ ‏.‏\hadithno{722}\hadithtrans{Ibn 'Abbas reported it on the authority of Maimuna, his mother's sister, that she said:I placed water near the Messenger of Allah (ﷺ) to take a bath because of sexual intercourse. He washed the palms of his bands twice or thrice and then put his hand In the basin and poured water over his private parts and washed them with his left hand. He then struck his hand against the earth and rubbed it with force and then performed ablution for the prayer and then poured three handfuls of water on his head and then washed his whole body after which he moved aside from that place and washed his feet, and then I brought a towel (so that he may wipe his body). but he returned it}}
\hadithdefcmd{muslim}{723}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ وَالأَشَجُّ وَإِسْحَاقُ كُلُّهُمْ عَنْ وَكِيعٍ، ح وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَيْسَ فِي حَدِيثِهِمَا إِفْرَاغُ ثَلاَثِ حَفَنَاتٍ عَلَى الرَّأْسِ وَفِي حَدِيثِ وَكِيعٍ وَصْفُ الْوُضُوءِ كُلِّهِ يَذْكُرُ الْمَضْمَضَةَ وَالاِسْتِنْشَاقَ فِيهِ وَلَيْسَ فِي حَدِيثِ أَبِي مُعَاوِيَةَ ذِكْرُ الْمِنْدِيلِ ‏.‏\hadithno{723}\hadithtrans{This hadith is narrated by A'mash with the same chain of transmitters, but in the hadith narrated by Yahya b. Yahya and Abu Kuraib there is no mention of:" Pouring of three handfuls of water on the head." and in the hadith narrated by Waki' all the features of ablution have been recorded: rinsing (of mouth), snuffing of water (in the nostrils) ; and in the hadith transmitted by Abu Mu'awyia, there is no mention of a towel}}
\hadithdefcmd{muslim}{724}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ الأَعْمَشِ، عَنْ سَالِمٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِمِنْدِيلٍ فَلَمْ يَمَسَّهُ وَجَعَلَ يَقُولُ بِالْمَاءِ هَكَذَا يَعْنِي يَنْفُضُهُ ‏.‏\hadithno{724}\hadithtrans{Ibn Abbas narrated It on the authority of Maimuna that the Messenger of Allah (ﷺ) was given a towel, but he did not rub (his body) with it, but he did like this with water, i. e. he shook it off}}
\hadithdefcmd{muslim}{725}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، حَدَّثَنِي أَبُو عَاصِمٍ، عَنْ حَنْظَلَةَ بْنِ أَبِي سُفْيَانَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ دَعَا بِشَىْءٍ نَحْوَ الْحِلاَبِ فَأَخَذَ بِكَفِّهِ بَدَأَ بِشِقِّ رَأْسِهِ الأَيْمَنِ ثُمَّ الأَيْسَرِ ثُمَّ أَخَذَ بِكَفَّيْهِ فَقَالَ بِهِمَا عَلَى رَأْسِهِ ‏.‏\hadithno{725}\hadithtrans{A'isha reported:When the Messenger of Allah (ﷺ) took a bath because of sexual intercourse, he called for a vessel and took a handful of water from it and first (washed) the right side of his head, then left, and then took a handful (of water) and poured it on his head}}
\hadithdefcmd{muslim}{726}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَغْتَسِلُ مِنْ إِنَاءٍ هُوَ الْفَرَقُ مِنَ الْجَنَابَةِ ‏.‏\hadithno{726}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) washed himself with water from a vessel (measuring seven to eight seers) because of sexual intercourse}}
\hadithdefcmd{muslim}{727}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ قَالُوا حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْتَسِلُ فِي الْقَدَحِ وَهُوَ الْفَرَقُ وَكُنْتُ أَغْتَسِلُ أَنَا وَهُوَ فِي الإِنَاءِ الْوَاحِدِ ‏.‏ وَفِي حَدِيثِ سُفْيَانَ مِنْ إِنَاءٍ وَاحِدٍ ‏.‏ قَالَ قُتَيْبَةُ قَالَ سُفْيَانُ وَالْفَرَقُ ثَلاَثَةُ آصُعٍ ‏.‏\hadithno{727}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) took a bath from the vessel (which contained seven to eight seers, i. e. fifteen to sixteen pounds) of water And I and he (the Holy Prophet) took a bath from the same vessel. And in the hadith narrated by Sufyan the words are:" from one vessel". Qutaiba said: Al-Faraq is three Sa' (a cubic measuring of varying magnitude)}}
\hadithdefcmd{muslim}{728}{وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بَكْرِ بْنِ حَفْصٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ أَنَا وَأَخُوهَا، مِنَ الرَّضَاعَةِ فَسَأَلَهَا عَنْ غُسْلِ النَّبِيِّ، صلى الله عليه وسلم مِنَ الْجَنَابَةِ فَدَعَتْ بِإِنَاءٍ قَدْرِ الصَّاعِ فَاغْتَسَلَتْ وَبَيْنَنَا وَبَيْنَهَا سِتْرٌ وَأَفْرَغَتْ عَلَى رَأْسِهَا ثَلاَثًا ‏.‏ قَالَ وَكَانَ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم يَأْخُذْنَ مِنْ رُءُوسِهِنَّ حَتَّى تَكُونَ كَالْوَفْرَةِ ‏.‏\hadithno{728}\hadithtrans{Abu Salamab. 'Abd al-Rahman reported:I along with the foster brother of 'A'isha went to her and he asked about the bath of the Apostle (ﷺ) because of sexual intercourse. She called for a vessel equal to a Sa' and she took a bath. and there was a curtain between us and her. She poured water on her head thrice and he (Abu Salama) said: The wives of the Apostle (ﷺ) collectedhair on their heads and these lopped up to ears (and did rot go beyond that)}}
\hadithdefcmd{muslim}{729}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ قَالَتْ عَائِشَةُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ بَدَأَ بِيَمِينِهِ فَصَبَّ عَلَيْهَا مِنَ الْمَاءِ فَغَسَلَهَا ثُمَّ صَبَّ الْمَاءَ عَلَى الأَذَى الَّذِي بِهِ بِيَمِينِهِ وَغَسَلَ عَنْهُ بِشِمَالِهِ حَتَّى إِذَا فَرَغَ مِنْ ذَلِكَ صَبَّ عَلَى رَأْسِهِ ‏.‏ قَالَتْ عَائِشَةُ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ وَنَحْنُ جُنُبَانِ ‏.‏\hadithno{729}\hadithtrans{Salama b. Abd al-Rahman narrated it on the authority of A'isha that when the Messenger of Allah (ﷺ) took a bath, he started from the right hand and poured water over it and washed it, and then poured water on the impurity with the right band and washed it away with the help of the left hand. and after having removed it, he poured water on his head. A'isha said:I and the Messenger of Allah (ﷺ) took a bath from the same vessel, after sexual intercourse}}
\hadithdefcmd{muslim}{730}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا لَيْثٌ، عَنْ يَزِيدَ، عَنْ عِرَاكٍ، عَنْ حَفْصَةَ بِنْتِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، - وَكَانَتْ تَحْتَ الْمُنْذِرِ بْنِ الزُّبَيْرِ - أَنَّ عَائِشَةَ، أَخْبَرَتْهَا أَنَّهَا، كَانَتْ تَغْتَسِلُ هِيَ وَالنَّبِيُّ صلى الله عليه وسلم فِي إِنَاءٍ وَاحِدٍ يَسَعُ ثَلاَثَةَ أَمْدَادٍ أَوْ قَرِيبًا مِنْ ذَلِكَ ‏.‏\hadithno{730}\hadithtrans{Hafsa, daughter of 'Abd al-Rahman b. Abu Bakr, reported that 'A'isha narrated to her that she and the Messenger of Allah (ﷺ) took a bath from the same vessel which contained water equal to three Mudds or thereabout}}
\hadithdefcmd{muslim}{731}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، قَالَ حَدَّثَنَا أَفْلَحُ بْنُ حُمَيْدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ تَخْتَلِفُ أَيْدِينَا فِيهِ مِنَ الْجَنَابَةِ ‏.‏\hadithno{731}\hadithtrans{A'isha reported:I and the Messenger (ﷺ) took a bath from the same vessel and our hands alternated into it in the state that we had had sexual intercourse}}
\hadithdefcmd{muslim}{732}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ مُعَاذَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم مِنْ إِنَاءٍ - بَيْنِي وَبَيْنَهُ - وَاحِدٍ فَيُبَادِرُنِي حَتَّى أَقُولَ دَعْ لِي دَعْ لِي ‏.‏ قَالَتْ وَهُمَا جُنُبَانِ ‏.‏\hadithno{732}\hadithtrans{A'isha reported:I and the Messenger of Allah (ﷺ) took a bath from one vessel which was placed between me and him and he would get ahead of me, so that I would say: Spare (some water for) me, spare (some water for) me; and she said that they had had sexual intercourse}}
\hadithdefcmd{muslim}{733}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، قَالَ قُتَيْبَةُ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ أَبِي الشَّعْثَاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَخْبَرَتْنِي مَيْمُونَةُ، أَنَّهَا كَانَتْ تَغْتَسِلُ هِيَ وَالنَّبِيُّ صلى الله عليه وسلم فِي إِنَاءٍ وَاحِدٍ ‏.‏\hadithno{733}\hadithtrans{Ibn Abbas said:Maimuna (the wife of the Holy Prophet) reported to me that she and the Messenger of Allah (ﷺ) took a bath from one vessel}}
\hadithdefcmd{muslim}{734}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ حَاتِمٍ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ ابْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، قَالَ أَكْبَرُ عِلْمِي وَالَّذِي يَخْطُرُ عَلَى بَالِي أَنَّ أَبَا الشَّعْثَاءِ أَخْبَرَنِي أَنَّ ابْنَ عَبَّاسٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَغْتَسِلُ بِفَضْلِ مَيْمُونَةَ ‏.‏\hadithno{734}\hadithtrans{Ibn Abbas reported that the Messenger of Allah (ﷺ) took a bath with the water left over by Maimuna}}
\hadithdefcmd{muslim}{735}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ زَيْنَبَ بِنْتَ أُمِّ سَلَمَةَ، حَدَّثَتْهُ أَنَّ أُمَّ سَلَمَةَ حَدَّثَتْهَا قَالَتْ، كَانَتْ هِيَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَغْتَسِلاَنِ فِي الإِنَاءِ الْوَاحِدِ مِنَ الْجَنَابَةِ ‏.‏\hadithno{735}\hadithtrans{Zainab bint Umm Salama (the wife of the Holy Prophet) reported that Umm Salama and the Messenger of Allah (ﷺ) took a bath from the same vessel}}
\hadithdefcmd{muslim}{736}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ جَبْرٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْتَسِلُ بِخَمْسِ مَكَاكِيكَ وَيَتَوَضَّأُ بِمَكُّوكٍ ‏.‏ وَقَالَ ابْنُ الْمُثَنَّى بِخَمْسِ مَكَاكِيَّ ‏.‏ وَقَالَ ابْنُ مُعَاذٍ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ وَلَمْ يَذْكُرِ ابْنَ جَبْرٍ ‏.‏\hadithno{736}\hadithtrans{Anas reported that the Messenger of Allah (may peace he upon him) took a bath with five Makkuks of water and performed ablution with one Makkuk. Ibn Muthanna has used the words five Makakiyya, and Ibn Mu'adh narrated it from 'Abdullah b. 'Abdullah and he made no mention of Ibn Jabr}}
\hadithdefcmd{muslim}{737}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنِ ابْنِ جَبْرٍ، عَنْ أَنَسِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَوَضَّأُ بِالْمُدِّ وَيَغْتَسِلُ بِالصَّاعِ إِلَى خَمْسَةِ أَمْدَادٍ ‏.‏\hadithno{737}\hadithtrans{Anas said:The Apostle of Allah (ﷺ) performed ablution with one Mudd and took bath with a Sa' up to five Mudds}}
\hadithdefcmd{muslim}{738}{وَحَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، وَعَمْرُو بْنُ عَلِيٍّ، كِلاَهُمَا عَنْ بِشْرِ بْنِ الْمُفَضَّلِ، - قَالَ أَبُو كَامِلٍ حَدَّثَنَا بِشْرٌ، - حَدَّثَنَا أَبُو رَيْحَانَةَ، عَنْ سَفِينَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُغَسِّلُهُ الصَّاعُ مِنَ الْمَاءِ مِنَ الْجَنَابَةِ وَيُوَضِّؤُهُ الْمُدُّ ‏.‏\hadithno{738}\hadithtrans{Safina reported:The Messenger of Allah (ﷺ) took a bath with one Sa` of water because of sexual intercourse and performed ablution with one Mudd}}
\hadithdefcmd{muslim}{739}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، ح وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَبِي رَيْحَانَةَ، عَنْ سَفِينَةَ، - قَالَ أَبُو بَكْرٍ - صَاحِبُ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْتَسِلُ بِالصَّاعِ وَيَتَطَهَّرُ بِالْمُدِّ ‏.‏ وَفِي حَدِيثِ ابْنِ حُجْرٍ أَوْ قَالَ وَيُطَهِّرُهُ الْمُدُّ ‏.‏ وَقَالَ وَقَدْ كَانَ كَبِرَ وَمَا كُنْتُ أَثِقُ بِحَدِيثِهِ ‏.‏\hadithno{739}\hadithtrans{Safina reported that Abu Bakr, the Companion of the Messenger of Allah (way peace be upon him), observed:The Messenger of Allah (ﷺ) took a bath with one Sa' of water and performed ablution with one Mudd (of water) ; and in the hadith narrated by Ibn Hujr the words are: One Mudd sufficed for his (Holy Prophet's) ablution. And Ibn Hujr said that (his Shaikh) Isma'il was much advanced in age, and it was because of this that he could not fully rely on him for this tradition}}
\hadithdefcmd{muslim}{740}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ سُلَيْمَانَ بْنِ صُرَدٍ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، قَالَ تَمَارَوْا فِي الْغُسْلِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ بَعْضُ الْقَوْمِ أَمَّا أَنَا فَإِنِّي أَغْسِلُ رَأْسِي كَذَا وَكَذَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمَّا أَنَا فَإِنِّي أُفِيضُ عَلَى رَأْسِي ثَلاَثَ أَكُفٍّ ‏"‏ ‏.‏\hadithno{740}\hadithtrans{Jubair b. Mut'im reported:The people contended amongst themselves in the presence of the Messenger of Allah (ﷺ) with regard to bathing. Some of them said: We wash our heads like this and this. Upon this the Messenger (ﷺ) said: As for me I pour three handfuls of water upon my head}}
\hadithdefcmd{muslim}{741}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ سُلَيْمَانَ بْنِ صُرَدٍ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ ذُكِرَ عِنْدَهُ الْغُسْلُ مِنَ الْجَنَابَةِ فَقَالَ ‏ "‏ أَمَّا أَنَا فَأُفْرِغُ عَلَى رَأْسِي ثَلاَثًا ‏"‏ ‏.‏\hadithno{741}\hadithtrans{Jubair b. Mut'im reported it from the Messenger of Allah (ﷺ) that a mention was made before him about bathing because of sexual intercourse and he said:I pour water over my head thrice}}
\hadithdefcmd{muslim}{742}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَإِسْمَاعِيلُ بْنُ سَالِمٍ، قَالاَ أَخْبَرَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ وَفْدَ، ثَقِيفٍ سَأَلُوا النَّبِيَّ صلى الله عليه وسلم فَقَالُوا إِنَّ أَرْضَنَا أَرْضٌ بَارِدَةٌ فَكَيْفَ بِالْغُسْلِ فَقَالَ ‏ "‏ أَمَّا أَنَا فَأُفْرِغُ عَلَى رَأْسِي ثَلاَثًا ‏"‏ ‏.‏ قَالَ ابْنُ سَالِمٍ فِي رِوَايَتِهِ حَدَّثَنَا هُشَيْمٌ أَخْبَرَنَا أَبُو بِشْرٍ وَقَالَ إِنَّ وَفْدَ ثَقِيفٍ قَالُوا يَا رَسُولَ اللَّهِ ‏.‏\hadithno{742}\hadithtrans{Jabir b. Abdullah reported:A delegation of the Thaqif said to the Messenger of Allah (ﷺ): Our land is cold; what about our bathing then? He (the Holy Prophet) said: I pour water thrice over my head. Ibn Salim in his narration reported:" The delegation of the Thaqif said: Messenger of Allah}}
\hadithdefcmd{muslim}{743}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي الثَّقَفِيَّ - حَدَّثَنَا جَعْفَرٌ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنْ جَنَابَةٍ صَبَّ عَلَى رَأْسِهِ ثَلاَثَ حَفَنَاتٍ مِنْ مَاءٍ ‏.‏ فَقَالَ لَهُ الْحَسَنُ بْنُ مُحَمَّدٍ إِنَّ شَعْرِي كَثِيرٌ ‏.‏ قَالَ جَابِرٌ فَقُلْتُ لَهُ يَا ابْنَ أَخِي كَانَ شَعْرُ رَسُولِ اللَّهِ صلى الله عليه وسلم أَكْثَرَ مِنْ شَعْرِكَ وَأَطْيَبَ ‏.‏\hadithno{743}\hadithtrans{Jabir b. 'Abdullah reported:When the Messenger of Allah (ﷺ) took a bath because of sexual intercourse, he poured three handfuls of water upon his head. Hasan b. Muhammad said to him (the narrator): My hair is thick. Upon this Jabir observed. I said to him: O son of my brother, the hair of the Messenger of Allah (ﷺ) was thicker than your hair and these were more fine (than yours)}}
\hadithdefcmd{muslim}{744}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، كُلُّهُمْ عَنِ ابْنِ عُيَيْنَةَ، قَالَ إِسْحَاقُ أَخْبَرَنَا سُفْيَانُ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، مَوْلَى أُمِّ سَلَمَةَ عَنْ أُمِّ سَلَمَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ أَشُدُّ ضَفْرَ رَأْسِي فَأَنْقُضُهُ لِغُسْلِ الْجَنَابَةِ قَالَ ‏ "‏ لاَ إِنَّمَا يَكْفِيكِ أَنْ تَحْثِي عَلَى رَأْسِكِ ثَلاَثَ حَثَيَاتٍ ثُمَّ تُفِيضِينَ عَلَيْكِ الْمَاءَ فَتَطْهُرِينَ ‏"‏ ‏.‏\hadithno{744}\hadithtrans{Umm Salama reported:I said: Messenger of Allah, I am a woman who has closely plaited hair on my head; should I undo it for taking a bath, because of sexual intercourse? He (the Holy Prophet) said: No, it is enough for you to throw three handfuls of water on your head and then pour water over yourself, and you shall be purified}}
\hadithdefcmd{muslim}{745}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، قَالاَ أَخْبَرَنَا الثَّوْرِيُّ، عَنْ أَيُّوبَ بْنِ مُوسَى، فِي هَذَا الإِسْنَادِ وَفِي حَدِيثِ عَبْدِ الرَّزَّاقِ فَأَنْقُضُهُ لِلْحَيْضَةِ وَالْجَنَابَةِ فَقَالَ ‏ "‏ لاَ ‏"‏ ثُمَّ ذَكَرَ بِمَعْنَى حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{745}\hadithtrans{This hadith has been narrated by Amr al-Naqid, Yazid b. Harun, 'Abd b. Humaid, Abd al-Razzaq, Thauri, Ayyub b. Musa, with the same chain of transmitters. In hadith narrated by Abd al-Razzaq there is a mention of the menstruation and of the sexual intercourse. The rest of the hadith has been transmitted like that of Ibn 'Uyaina}}
\hadithdefcmd{muslim}{746}{وَحَدَّثَنِيهِ أَحْمَدُ الدَّارِمِيُّ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ عَدِيٍّ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - عَنْ رَوْحِ بْنِ الْقَاسِمِ، حَدَّثَنَا أَيُّوبُ بْنُ مُوسَى، بِهَذَا الإِسْنَادِ وَقَالَ أَفَأَحُلُّهُ فَأَغْسِلُهُ مِنَ الْجَنَابَةِ ‏.‏ وَلَمْ يَذْكُرِ الْحَيْضَةَ ‏.‏\hadithno{746}\hadithtrans{This hadith is narrated by the same chain of transmitters by Ahmad al. Darimi, Zakariya b. 'Adi, Yazid, i. e. ' Ibn Zurai', Rauh b. al-Qasim, Ayyub b. Musa with the same chain of transmitters, and there is a mention of these words:" Should I undo the plait and wash it, because of sexual intercourse?" and there is no mention of menstruation}}
\hadithdefcmd{muslim}{747}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَلِيُّ بْنُ حُجْرٍ جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، قَالَ يَحْيَى أَخْبَرَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، قَالَ بَلَغَ عَائِشَةَ أَنَّ عَبْدَ، اللَّهِ بْنَ عَمْرٍو يَأْمُرُ النِّسَاءَ إِذَا اغْتَسَلْنَ أَنْ يَنْقُضْنَ رُءُوسَهُنَّ فَقَالَتْ يَا عَجَبًا لاِبْنِ عَمْرٍو هَذَا يَأْمُرُ النِّسَاءَ إِذَا اغْتَسَلْنَ أَنْ يَنْقُضْنَ رُءُوسَهُنَّ أَفَلاَ يَأْمُرُهُنَّ أَنْ يَحْلِقْنَ رُءُوسَهُنَّ لَقَدْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ وَلاَ أَزِيدُ عَلَى أَنْ أُفْرِغَ عَلَى رَأْسِي ثَلاَثَ إِفْرَاغَاتٍ ‏.‏\hadithno{747}\hadithtrans{Ubaid b. Umair reported:It was conveyed to 'A'isha that 'Abdullah b. 'Amr ordered the women to undo the (plaits) of hair on their heads. She said: How strange it is for Ibn 'Amr that he orders the women to undo the plaits of their head while taking a bath; why does he not order them to shave their beads? I and the Messenger of Allah (ﷺ) took bath from one vessel. I did no more than this that I poured three handfuls of water over my head}}
\hadithdefcmd{muslim}{748}{حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنْ مَنْصُورٍ ابْنِ صَفِيَّةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ سَأَلَتِ امْرَأَةٌ النَّبِيَّ صلى الله عليه وسلم كَيْفَ تَغْتَسِلُ مِنْ حَيْضَتِهَا قَالَ فَذَكَرَتْ أَنَّهُ عَلَّمَهَا كَيْفَ تَغْتَسِلُ ثُمَّ تَأْخُذُ فِرْصَةً مِنْ مِسْكٍ فَتَطَهَّرُ بِهَا ‏.‏ قَالَتْ كَيْفَ أَتَطَهَّرُ بِهَا قَالَ ‏ "‏ تَطَهَّرِي بِهَا ‏.‏ سُبْحَانَ اللَّهِ ‏"‏ ‏.‏ وَاسْتَتَرَ - وَأَشَارَ لَنَا سُفْيَانُ بْنُ عُيَيْنَةَ بِيَدِهِ عَلَى وَجْهِهِ - قَالَ قَالَتْ عَائِشَةُ وَاجْتَذَبْتُهَا إِلَىَّ وَعَرَفْتُ مَا أَرَادَ النَّبِيُّ صلى الله عليه وسلم فَقُلْتُ تَتَبَّعِي بِهَا أَثَرَ الدَّمِ ‏.‏ وَقَالَ ابْنُ أَبِي عُمَرَ فِي رِوَايَتِهِ فَقُلْتُ تَتَبَّعِي بِهَا آثَارَ الدَّمِ ‏.‏\hadithno{748}\hadithtrans{A'isha reported:A woman asked the Messenger of Allah (ﷺ) how to wash herself after menstruation. She mentioned that he taught her how to take bath and then told her to take a piece of cotton with musk and purify herself. She said: How should I purify myself with that? He (the Holy Prophet) said: Praise be to Allah, purify yourself with it, and covered his face, Sufyan b. 'Uyaina gave a demonstration by covering his face (as the Prophet had done). 'A'isha reported: I dragged her to my side for I had understood what the Messenger of Allah (ﷺ) intended and, therefore, said: Apply this cotton with musk to the trace of blood. Ibn 'Umar in his hadith (has mentioned the words of 'A'isha thus): Apply it to the marks of blood}}
\hadithdefcmd{muslim}{749}{وَحَدَّثَنِي أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مَنْصُورٌ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم كَيْفَ أَغْتَسِلُ عِنْدَ الطُّهْرِ فَقَالَ ‏ "‏ خُذِي فِرْصَةً مُمَسَّكَةً فَتَوَضَّئِي بِهَا ‏"‏ ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِ سُفْيَانَ ‏.‏\hadithno{749}\hadithtrans{A'isha reported:A woman asked the Messenger of Allah (ﷺ) how he should wash herself after the menstrual period. He (the Holy Prophet) said: Take a cotton with musk and purity yourself, and the rest of the hadith was narrated like that of Sufyan}}
\hadithdefcmd{muslim}{750}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ إِبْرَاهِيمَ بْنِ الْمُهَاجِرِ، قَالَ سَمِعْتُ صَفِيَّةَ، تُحَدِّثُ عَنْ عَائِشَةَ، أَنَّ أَسْمَاءَ، سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم عَنْ غُسْلِ الْمَحِيضِ فَقَالَ ‏"‏ تَأْخُذُ إِحْدَاكُنَّ مَاءَهَا وَسِدْرَتَهَا فَتَطَهَّرُ فَتُحْسِنُ الطُّهُورَ ثُمَّ تَصُبُّ عَلَى رَأْسِهَا فَتَدْلُكُهُ دَلْكًا شَدِيدًا حَتَّى تَبْلُغَ شُئُونَ رَأْسِهَا ثُمَّ تَصُبُّ عَلَيْهَا الْمَاءَ ‏.‏ ثُمَّ تَأْخُذُ فِرْصَةً مُمَسَّكَةً فَتَطَهَّرُ بِهَا ‏"‏ ‏.‏ فَقَالَتْ أَسْمَاءُ وَكَيْفَ تَطَهَّرُ بِهَا فَقَالَ ‏"‏ سُبْحَانَ اللَّهِ تَطَهَّرِينَ بِهَا ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ كَأَنَّهَا تُخْفِي ذَلِكَ تَتَبَّعِينَ أَثَرَ الدَّمِ ‏.‏ وَسَأَلَتْهُ عَنْ غُسْلِ الْجَنَابَةِ فَقَالَ ‏"‏ تَأْخُذُ مَاءً فَتَطَهَّرُ فَتُحْسِنُ الطُّهُورَ - أَوْ تُبْلِغُ الطُّهُورَ - ثُمَّ تَصُبُّ عَلَى رَأْسِهَا فَتَدْلُكُهُ حَتَّى تَبْلُغَ شُئُونَ رَأْسِهَا ثُمَّ تُفِيضُ عَلَيْهَا الْمَاءَ ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ نِعْمَ النِّسَاءُ نِسَاءُ الأَنْصَارِ لَمْ يَكُنْ يَمْنَعُهُنَّ الْحَيَاءُ أَنْ يَتَفَقَّهْنَ فِي الدِّينِ ‏.‏\hadithno{750}\hadithtrans{A'isha reported:Asma (daughter of Shakal) asked the Messenger of Allah (ﷺ) about washing after menstruation. He said: Everyone amongst you should use water (mixed with the leaves of) the lote-tree and cleanse herself well, and then pour water on her head and rub it vigorously till it reaches the roots of the hair. Then she should pour water on it. Afterwards she should take a piece of cotton smeared with musk and cleanse herself with it. Asma' said: How should she cleanse herself with the help of that? Upon this he (the Messenger of Allah) observed: Praise be to Allah, she should cleanse herself. 'A'isha said in a subdued tone that she should apply it to the trace of blood. She (Asma) then further asked about bathing after sexual intercourse. He (the Holy Prophet) said: She should take water and cleanse herself well or complete the ablution and then (pour water) on her head and rub it till it reaches the roots of the hair (of her) head and then pour water on her. 'A'isha said: How good are the women of Ansar (helpers) that their shyness does not prevent them from learning religion}}
\hadithdefcmd{muslim}{751}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، فِي هَذَا الإِسْنَادِ نَحْوَهُ وَقَالَ قَالَ ‏ "‏ سُبْحَانَ اللَّهِ تَطَهَّرِي بِهَا ‏"‏ ‏.‏ وَاسْتَتَرَ ‏.‏\hadithno{751}\hadithtrans{This hadith is narrated by 'Ubaidullah b. Mu'adh with the same chain of transmitters (but for the words) that he (the Holy Prophet) said:Cleanse yourself with it, and he covered (his face on account of shyness)}}
\hadithdefcmd{muslim}{752}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ كِلاَهُمَا عَنْ أَبِي الأَحْوَصِ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَتْ أَسْمَاءُ بِنْتُ شَكَلٍ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ كَيْفَ تَغْتَسِلُ إِحْدَانَا إِذَا طَهُرَتْ مِنَ الْحَيْضِ وَسَاقَ الْحَدِيثَ وَلَمْ يَذْكُرْ فِيهِ غُسْلَ الْجَنَابَةِ ‏.‏\hadithno{752}\hadithtrans{A'isha reported:Asma' b. Shakal came to the Messenger of Allah (ﷺ) and said: Messenger of Allah, how one amongst us should take a bath after the menstruation, and the rest of the hadith is the same and there is no mention of bathing because of sexual intercourse}}
\hadithdefcmd{muslim}{753}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ أُسْتَحَاضُ فَلاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ فَقَالَ ‏ "‏ لاَ إِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَ بِالْحَيْضَةِ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ وَصَلِّي ‏"‏ ‏.‏\hadithno{753}\hadithtrans{A'isha reported:Fatimah b. Abu Hubaish came to the Apostle (ﷺ) and said: I am a woman whose blood keeps flowing (even after the menstruation period). I am never purified; should I, therefore, abandon prayer? He (the Holy Prophet) said: Not at all, for that is only a vein, and is not a menstruation, so when menstruation comes, abandon prayer, and when it ends wash the blood from yourself and then pray}}
\hadithdefcmd{muslim}{754}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، كُلُّهُمْ عَنْ هِشَامِ بْنِ عُرْوَةَ، بِمِثْلِ حَدِيثِ وَكِيعٍ وَإِسْنَادِهِ ‏.‏ وَفِي حَدِيثِ قُتَيْبَةَ عَنْ جَرِيرٍ جَاءَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشِ بْنِ عَبْدِ الْمُطَّلِبِ بْنِ أَسَدٍ وَهِيَ امْرَأَةٌ مِنَّا ‏.‏ قَالَ وَفِي حَدِيثِ حَمَّادِ بْنِ زَيْدٍ زِيَادَةُ حَرْفٍ تَرَكْنَا ذِكْرَهُ ‏.‏\hadithno{754}\hadithtrans{The hadith narrated by Waki' and with its chain of narrators has been transmitted on the authority of Hisham b. 'Urwa, but in the hadith narrated by Qutaiba on the authority of Jarir, the words are:" There came Fatimah b. Abu Hubaish, b. 'Abd al-Muttalib b. Asad, and she was a woman amongst us," and in the hadith of Hammid b. Zaid there is an addition of these words:" We abandoned mentioning him}}
\hadithdefcmd{muslim}{755}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتِ اسْتَفْتَتْ أُمُّ حَبِيبَةَ بِنْتُ جَحْشٍ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنِّي أُسْتَحَاضُ ‏.‏ فَقَالَ ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ فَاغْتَسِلِي ثُمَّ صَلِّي ‏"‏ ‏.‏ فَكَانَتْ تَغْتَسِلُ عِنْدَ كُلِّ صَلاَةٍ ‏.‏ قَالَ اللَّيْثُ بْنُ سَعْدٍ لَمْ يَذْكُرِ ابْنُ شِهَابٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ أُمَّ حَبِيبَةَ بِنْتَ جَحْشٍ أَنْ تَغْتَسِلَ عِنْدَ كُلِّ صَلاَةٍ وَلَكِنَّهُ شَىْءٌ فَعَلَتْهُ هِيَ ‏.‏ وَقَالَ ابْنُ رُمْحٍ فِي رِوَايَتِهِ ابْنَةُ جَحْشٍ وَلَمْ يَذْكُرْ أُمَّ حَبِيبَةَ ‏.‏\hadithno{755}\hadithtrans{A'isha reported:Umm Habiba b. Jahsh thus asked for a verdict from the Messenger of Allah (ﷺ): I am a woman whose blood keeps flowing (after the menstrual period). He (the Holy Prophet) said: That is only a vein, so take a bath and offer prayer; and she took a bath at the time of every prayer. Laith b. Sa'd said: Ibn Shihab made no mention that the Messenger of Allah (ﷺ) had ordered her to take a bath at the time of every prayer, but she did it of her own accord. And in the tradition transmitted by Ibn Rumh there is no mention of Umm Habiba (and there is mention of the daughter of Jahsh only)}}
\hadithdefcmd{muslim}{756}{وَحَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ أُمَّ حَبِيبَةَ بِنْتَ جَحْشٍ - خَتَنَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَتَحْتَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ - اسْتُحِيضَتْ سَبْعَ سِنِينَ فَاسْتَفْتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ هَذِهِ لَيْسَتْ بِالْحَيْضَةِ وَلَكِنَّ هَذَا عِرْقٌ فَاغْتَسِلِي وَصَلِّي ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَكَانَتْ تَغْتَسِلُ فِي مِرْكَنٍ فِي حُجْرَةِ أُخْتِهَا زَيْنَبَ بِنْتِ جَحْشٍ حَتَّى تَعْلُوَ حُمْرَةُ الدَّمِ الْمَاءَ ‏.‏ قَالَ ابْنُ شِهَابٍ فَحَدَّثْتُ بِذَلِكَ أَبَا بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ فَقَالَ يَرْحَمُ اللَّهُ هِنْدًا لَوْ سَمِعَتْ بِهَذِهِ الْفُتْيَا وَاللَّهِ إِنْ كَانَتْ لَتَبْكِي لأَنَّهَا كَانَتْ لاَ تُصَلِّي ‏.‏\hadithno{756}\hadithtrans{A'isha, the wife of the Messenger of Allah (ﷺ) reported:Umm Habiba b. Jahsh who was the sister-in-law of the Messenger of Allah (ﷺ) and the wife of 'Abd al-Rahman b. Auf, remained mustahada for seven years, and she, therefore, asked for the verdict of Shari'ah from the Messenger of Allah (ﷺ) about it The Messenger of Allah (ﷺ) said: This is not menstruation, but (blood from) a vein: so bathe yourself and offer prayer. 'A'isha said: She took a bath in the wash-tub placed in the apartment of her sister Zainab b. Jahsh, till the redness of the blood came over the water. Ibn Shihab said: I narrated it to Abu Bakr b. 'Abd al-Rahman b. al-Harith b. Hisham about it who observed: May Allah have mercy on Hinda! would that she listened to this verdict. By Lord, she wept for not offering prayer}}
\hadithdefcmd{muslim}{757}{وَحَدَّثَنِي أَبُو عِمْرَانَ، مُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ أَخْبَرَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ سَعْدٍ - عَنِ ابْنِ شِهَابٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ أُمُّ حَبِيبَةَ بِنْتُ جَحْشٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَتِ اسْتُحِيضَتْ سَبْعَ سِنِينَ بِمِثْلِ حَدِيثِ عَمْرِو بْنِ الْحَارِثِ إِلَى قَوْلِهِ تَعْلُوَ حُمْرَةُ الدَّمِ الْمَاءَ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ ‏.‏\hadithno{757}\hadithtrans{This hadith has been thus reported by another chain of transmitters:Umm Habiba b. Jahsh came to the Messenger of Allah (ﷺ) and she had been a mustahada for seven years, and the rest of the hadith was narrated like that of 'Amr b. al-Harith up to the words:" There came the redness of the blood over water." and nothing was narrated beyond it}}
\hadithdefcmd{muslim}{758}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ ابْنَةَ جَحْشٍ، كَانَتْ تُسْتَحَاضُ سَبْعَ سِنِينَ بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{758}\hadithtrans{The hadith has been narrated by 'A'isha through another chain of transmitters (in these words):I The daughter of jahsh had been mustabida for seven years," and the rest of the hadith is the same (as mentioned above)}}
\hadithdefcmd{muslim}{759}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيِبٍ، عَنْ جَعْفَرٍ، عَنْ عِرَاكٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ إِنَّ أُمَّ حَبِيبَةَ سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الدَّمِ فَقَالَتْ عَائِشَةُ رَأَيْتُ مِرْكَنَهَا مَلآنَ دَمًا فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ امْكُثِي قَدْرَ مَا كَانَتْ تَحْبِسُكِ حَيْضَتُكِ ثُمَّ اغْتَسِلِي وَصَلِّي ‏"‏ ‏.‏\hadithno{759}\hadithtrans{On the authority of 'A'isha:Umm Habiba asked the Messenger of Allah (ﷺ) about the blood (which flows beyond the period of menstruation). 'A'isha said: I saw her wash-tub full of blood. The Messenger of Allah (ﷺ) said: Remain away (from prayer) equal (to the length of time) that your menses prevented you. After this (after the period of usual courses) bathe yourself and offer prayer}}
\hadithdefcmd{muslim}{760}{حَدَّثَنِي مُوسَى بْنُ قُرَيْشٍ التَّمِيمِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ بَكْرِ بْنِ مُضَرَ، حَدَّثَنِي أَبِي، حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ إِنَّ أُمَّ حَبِيبَةَ بِنْتَ جَحْشٍ الَّتِي كَانَتْ تَحْتَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ شَكَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الدَّمَ فَقَالَ لَهَا ‏ "‏ امْكُثِي قَدْرَ مَا كَانَتْ تَحْبِسُكِ حَيْضَتُكِ ثُمَّ اغْتَسِلِي ‏"‏ ‏.‏ فَكَانَتْ تَغْتَسِلُ عِنْدَ كُلِّ صَلاَةٍ ‏.‏\hadithno{760}\hadithtrans{A'isha, the wife of the Apostle (ﷺ), said:Umm Habiba b. Jahsh who was the spouse of Abd al- Rahman b. Auf made a complaint to the Messenger of Allah (ﷺ) about blood (which flows beyond the menstrual period). He said to her: Remain away (from prayer) equal (to the length of time) that your menstruation holds you back. After this, bathe yourself. And she washed herself before every prayer}}
\hadithdefcmd{muslim}{761}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ مُعَاذَةَ، ح وَحَدَّثَنَا حَمَّادٌ، عَنْ يَزِيدَ الرِّشْكِ، عَنْ مُعَاذَةَ، أَنَّ امْرَأَةً، سَأَلَتْ عَائِشَةَ فَقَالَتْ أَتَقْضِي إِحْدَانَا الصَّلاَةَ أَيَّامَ مَحِيضِهَا فَقَالَتْ عَائِشَةُ أَحَرُورِيَّةٌ أَنْتِ قَدْ كَانَتْ إِحْدَانَا تَحِيضُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ لاَ تُؤْمَرُ بِقَضَاءٍ ‏.‏\hadithno{761}\hadithtrans{Mu'adha reported:A woman asked 'A'isha: Should one amongst us complete prayers abandoned during the period of menses? 'A'isha said: Are you a Haruriya? When any one of us during the time of the Messenger of Allah (ﷺ) was in her menses (and abandoned prayer) she was not required to complete them}}
\hadithdefcmd{muslim}{762}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ، قَالَ سَمِعْتُ مُعَاذَةَ، أَنَّهَا سَأَلَتْ عَائِشَةَ أَتَقْضِي الْحَائِضُ الصَّلاَةَ فَقَالَتْ عَائِشَةُ أَحَرُورِيَّةٌ أَنْتِ قَدْ كُنَّ نِسَاءُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَحِضْنَ أَفَأَمَرَهُنَّ أَنْ يَجْزِينَ قَالَ مُحَمَّدُ بْنُ جَعْفَرٍ تَعْنِي يَقْضِينَ ‏.‏\hadithno{762}\hadithtrans{It is reported from Mu'adha that she asked 'A'isha:Should a menstruating woman complete the prayer (abandoned during the menstrual period)? 'A'isha said: Are you a Hurariya? The wives of the Messenger of Allah (ﷺ) have had their monthly courses, (but) did he order them to make compensation (for the abandoned prayers)? Muhammad b. Ja'far said: (Compensation) denotes their completion}}
\hadithdefcmd{muslim}{763}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ عَاصِمٍ، عَنْ مُعَاذَةَ، قَالَتْ سَأَلْتُ عَائِشَةَ فَقُلْتُ مَا بَالُ الْحَائِضِ تَقْضِي الصَّوْمَ وَلاَ تَقْضِي الصَّلاَةَ فَقَالَتْ أَحَرُورِيَّةٌ أَنْتِ قُلْتُ لَسْتُ بِحَرُورِيَّةٍ وَلَكِنِّي أَسْأَلُ ‏.‏ قَالَتْ كَانَ يُصِيبُنَا ذَلِكَ فَنُؤْمَرُ بِقَضَاءِ الصَّوْمِ وَلاَ نُؤْمَرُ بِقَضَاءِ الصَّلاَةِ ‏.‏\hadithno{763}\hadithtrans{Mu'adha said:I asked 'A'isha: What is the reason that a menstruating woman completes the fasts (that she abandons during her monthly course). but she does not complete the prayers? She (Hadrat 'A'isha) said: Are you a Haruriya? I said: I am not a Haruriya, but I simply want to inquire. She said: We passed through this (period of menstruation), and we were ordered to complete the fasts, but were not ordered to complete the prayers}}
\hadithdefcmd{muslim}{764}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي النَّضْرِ، أَنَّ أَبَا مُرَّةَ، مَوْلَى أُمِّ هَانِئٍ بِنْتِ أَبِي طَالِبٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أُمَّ هَانِئٍ بِنْتَ أَبِي طَالِبٍ، تَقُولُ ذَهَبْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ فَوَجَدْتُهُ يَغْتَسِلُ ‏.‏ وَفَاطِمَةُ ابْنَتُهُ تَسْتُرُهُ بِثَوْبٍ ‏.‏\hadithno{764}\hadithtrans{Umm Hani b. Abu Talib reported:I went to the Messenger of Allah (ﷺ) on the day of the conquest (of Mecca) and found him take a bath. while his daughter Fatimah was holding a curtain around him}}
\hadithdefcmd{muslim}{765}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، أَنَّ أَبَا مُرَّةَ، مَوْلَى عَقِيلٍ حَدَّثَهُ أَنَّ أُمَّ هَانِئٍ بِنْتَ أَبِي طَالِبٍ حَدَّثَتْهُ أَنَّهُ، لَمَّا كَانَ عَامُ الْفَتْحِ أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ بِأَعْلَى مَكَّةَ ‏.‏ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى غُسْلِهِ فَسَتَرَتْ عَلَيْهِ فَاطِمَةُ ثُمَّ أَخَذَ ثَوْبَهُ فَالْتَحَفَ بِهِ ثُمَّ صَلَّى ثَمَانَ رَكَعَاتٍ سُبْحَةَ الضُّحَى ‏.‏\hadithno{765}\hadithtrans{Umm Hani b. Abu Talib reported:It was the day of the conquest (of Mecca) that she went to the Messenger of Allah (ﷺ) and he was staying at a higher part (of that city). The Messenger of Allah (ﷺ) got up for his bath. Fatimah held a curtain around him (in order to provide him privacy). He then put on his garments and wrapped himself with that and then offered eight rak'ahs of the forenoon prayer}}
\hadithdefcmd{muslim}{766}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، بِهَذَا الإِسْنَادِ وَقَالَ فَسَتَرَتْهُ ابْنَتُهُ فَاطِمَةُ بِثَوْبِهِ فَلَمَّا اغْتَسَلَ أَخَذَهُ فَالْتَحَفَ بِهِ ثُمَّ قَامَ فَصَلَّى ثَمَانَ سَجَدَاتٍ وَذَلِكَ ضُحًى ‏.‏\hadithno{766}\hadithtrans{This hadith is narrated by Sa'id b. Abu Hind with the same chain of transmitters and said:His (the Holy Prophet's) daughter Fatimah provided him privacy with the help of his cloth, and when he had taken a bath he took it up and wrapped it around him and then stood and offered eight rak'ahs of the forenoon prayer}}
\hadithdefcmd{muslim}{767}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا مُوسَى الْقَارِئُ، حَدَّثَنَا زَائِدَةُ، عَنِ الأَعْمَشِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، قَالَتْ وَضَعْتُ لِلنَّبِيِّ صلى الله عليه وسلم مَاءً وَسَتَرْتُهُ فَاغْتَسَلَ ‏.‏\hadithno{767}\hadithtrans{Maimuna reported:I placed water for the Apostle (ﷺ) and provided privacy for him, and he took a bath}}
\hadithdefcmd{muslim}{768}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، قَالَ أَخْبَرَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْظُرُ الرَّجُلُ إِلَى عَوْرَةِ الرَّجُلِ وَلاَ الْمَرْأَةُ إِلَى عَوْرَةِ الْمَرْأَةِ وَلاَ يُفْضِي الرَّجُلُ إِلَى الرَّجُلِ فِي ثَوْبٍ وَاحِدٍ وَلاَ تُفْضِي الْمَرْأَةُ إِلَى الْمَرْأَةِ فِي الثَّوْبِ الْوَاحِدِ ‏"‏ ‏.‏\hadithno{768}\hadithtrans{Abd al-Rahman, the son of Abu Sa'id al-Khudri, reported from his father:The Messenger of Allah (ﷺ) said: A man should not see the private parts of another man, and a woman should not see the private parts of another woman, and a man should not lie with another man under one covering, and a woman should not lie with another woman under one covering}}
\hadithdefcmd{muslim}{769}{وَحَدَّثَنِيهِ هَارُونُ بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ بْنُ عُثْمَانَ، بِهَذَا الإِسْنَادِ وَقَالاَ - مَكَانَ عَوْرَةِ - عُرْيَةِ الرَّجُلِ وَعُرْيَةِ الْمَرْأَةِ ‏.‏\hadithno{769}\hadithtrans{This hadith has been narrated by Ibn Abu Fudaik and Dabbik b. 'Uthman with the same chain of transmitters and they observed:Private parts of man are the nakedness (which is concealed)}}
\hadithdefcmd{muslim}{770}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ مُحَمَّدٍ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَانَتْ بَنُو إِسْرَائِيلَ يَغْتَسِلُونَ عُرَاةً يَنْظُرُ بَعْضُهُمْ إِلَى سَوْأَةِ بَعْضٍ وَكَانَ مُوسَى - عَلَيْهِ السَّلاَمُ - يَغْتَسِلُ وَحْدَهُ فَقَالُوا وَاللَّهِ مَا يَمْنَعُ مُوسَى أَنْ يَغْتَسِلَ مَعَنَا إِلاَّ أَنَّهُ آدَرُ - قَالَ - فَذَهَبَ مَرَّةً يَغْتَسِلُ فَوَضَعَ ثَوْبَهُ عَلَى حَجَرٍ فَفَرَّ الْحَجَرُ بِثَوْبِهِ - قَالَ - فَجَمَحَ مُوسَى بِإِثْرِهِ يَقُولُ ثَوْبِي حَجَرُ ثَوْبِي حَجَرُ ‏.‏ حَتَّى نَظَرَتْ بَنُو إِسْرَائِيلَ إِلَى سَوْأَةِ مُوسَى قَالُوا وَاللَّهِ مَا بِمُوسَى مِنْ بَأْسٍ ‏.‏ فَقَامَ الْحَجَرُ حَتَّى نُظِرَ إِلَيْهِ - قَالَ - فَأَخَذَ ثَوْبَهُ فَطَفِقَ بِالْحَجَرِ ضَرْبًا ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ وَاللَّهِ إِنَّهُ بِالْحَجَرِ نَدَبٌ سِتَّةٌ أَوْ سَبْعَةٌ ضَرْبُ مُوسَى بِالْحَجَرِ ‏.‏\hadithno{770}\hadithtrans{Amongst the traditions narrated from Muhammad, the Messenger of Allah (ﷺ) on the authority of Abu Huraira, the one is that Banu Isra'il used to take a bath naked, and they looked at the private parts of one another. Moses (peace be upon him), however, took a bath alone (in privacy) ; and they said (tauntingly):By Allah, nothing prohibits Moses to take a bath along with us, but sacrotal hernia. He (Moses) once went for a bath and placed his clothes on a stone and the stone moved on with his clothes. Moses ran after it saying: 0 stone, my clothes,0 stone, my clothes, and Banu Isra'il had the chance to see the private parts of Moses, and said: By Allah, Moses does not suffer from any ailment. The stone then stopped, till Moses had been seen by them, and he then took hold of his clothes and struck the stone. Abu Huraira said: By Allah, there are the marks of six or seven strokes made by Moses on the stone}}
\hadithdefcmd{muslim}{771}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَمُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، جَمِيعًا عَنْ مُحَمَّدِ بْنِ بَكْرٍ، قَالَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَاللَّفْظُ، لَهُمَا - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ لَمَّا بُنِيَتِ الْكَعْبَةُ ذَهَبَ النَّبِيُّ صلى الله عليه وسلم وَعَبَّاسٌ يَنْقُلاَنِ حِجَارَةً فَقَالَ الْعَبَّاسُ لِلنَّبِيِّ صلى الله عليه وسلم اجْعَلْ إِزَارَكَ عَلَى عَاتِقِكَ مِنَ الْحِجَارَةِ ‏.‏ فَفَعَلَ فَخَرَّ إِلَى الأَرْضِ وَطَمَحَتْ عَيْنَاهُ إِلَى السَّمَاءِ ثُمَّ قَامَ فَقَالَ ‏ "‏ إِزَارِي إِزَارِي ‏"‏ ‏.‏ فَشَدَّ عَلَيْهِ إِزَارَهُ ‏.‏ قَالَ ابْنُ رَافِعٍ فِي رِوَايَتِهِ عَلَى رَقَبَتِكَ ‏.‏ وَلَمْ يَقُلْ عَلَى عَاتِقِكَ ‏.‏\hadithno{771}\hadithtrans{Jabir b. 'Abdullah reported:When the Ka'ba was constructed the Messenger of Allah (ﷺ) and Abbas went and lifted stones. Abbas said to the Messenger of Allah (ﷺ): Place your lower garment on your shoulder (so that you may protect yourself from the roughness and hardness of stones). He (the Holy Prophet) did this, but fell down upon the ground in a state of unconciousness and his eyes were turned towards the sky. He then stood up and said: My lower garment, my lower garment; and this wrapper was tied around him. In the hadith transmitted by Ibn Rafi', there is the word:" On his neck" and he did not say:" Upon his shoulder}}
\hadithdefcmd{muslim}{772}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَنْقُلُ مَعَهُمُ الْحِجَارَةَ لِلْكَعْبَةِ وَعَلَيْهِ إِزَارُهُ فَقَالَ لَهُ الْعَبَّاسُ عَمُّهُ يَا ابْنَ أَخِي لَوْ حَلَلْتَ إِزَارَكَ فَجَعَلْتَهُ عَلَى مَنْكِبِكَ دُونَ الْحِجَارَةِ - قَالَ - فَحَلَّهُ فَجَعَلَهُ عَلَى مَنْكِبِهِ فَسَقَطَ مَغْشِيًّا عَلَيْهِ - قَالَ - فَمَا رُؤِيَ بَعْدَ ذَلِكَ الْيَوْمِ عُرْيَانًا ‏.‏\hadithno{772}\hadithtrans{Jabir b. 'Abdullah reported:The Messenger of Allah (ﷺ) was carrying along with them (his people) stones for the Ka'ba and there was a waist wrapper around him. His uncle," Abbas, said to him: 0 son of my brother! if you take off the lower garment and place it on the shoulders underneath the stones, it would be better. He (the Holy Prophet) took it off and placed it on his shoulder and fell down unconscious. He (the narrator) said: Never was he seen naked after that day}}
\hadithdefcmd{muslim}{773}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى الأُمَوِيُّ، حَدَّثَنِي أَبِي، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمِ بْنِ عَبَّادِ بْنِ حُنَيْفٍ الأَنْصَارِيُّ، أَخْبَرَنِي أَبُو أُمَامَةَ بْنُ سَهْلِ بْنِ حُنَيْفٍ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ أَقْبَلْتُ بِحَجَرٍ أَحْمِلُهُ ثَقِيلٍ وَعَلَىَّ إِزَارٌ خَفِيفٌ - قَالَ - فَانْحَلَّ إِزَارِي وَمَعِيَ الْحَجَرُ لَمْ أَسْتَطِعْ أَنْ أَضَعَهُ حَتَّى بَلَغْتُ بِهِ إِلَى مَوْضِعِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ارْجِعْ إِلَى ثَوْبِكَ فَخُذْهُ وَلاَ تَمْشُوا عُرَاةً ‏"‏ ‏.‏\hadithno{773}\hadithtrans{Al-Miswar b. Makhrama reported:I was carrying a heavy stone and my lower garment was loose, and it, therefore, slipped off (so soon) that I could not place the stone (on the ground) and carry to its proper place. Upon this the Messenger of Allah (ﷺ) said: Return to your cloth (lower garment), take it (and tie it around your waist) and do not walk naked}}
\hadithdefcmd{muslim}{774}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، وَعَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، قَالاَ حَدَّثَنَا مَهْدِيٌّ، - وَهُوَ ابْنُ مَيْمُونٍ - حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي يَعْقُوبَ، عَنِ الْحَسَنِ بْنِ سَعْدٍ، مَوْلَى الْحَسَنِ بْنِ عَلِيٍّ عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ أَرْدَفَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ خَلْفَهُ فَأَسَرَّ إِلَىَّ حَدِيثًا لاَ أُحَدِّثُ بِهِ أَحَدًا مِنَ النَّاسِ وَكَانَ أَحَبَّ مَا اسْتَتَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم لِحَاجَتِهِ هَدَفٌ أَوْ حَائِشُ نَخْلٍ ‏.‏ قَالَ ابْنُ أَسْمَاءَ فِي حَدِيثِهِ يَعْنِي حَائِطَ نَخْلٍ ‏.‏\hadithno{774}\hadithtrans{Abdullah b. Ja'far reported:The Messenger of Allah (ﷺ) one day made me mount behind him and he confided to me something secret which I would not disclose to anybody; and the Messenger of Allah (ﷺ) liked the concealment provided by a lofty place or cluster of dates (while answering the call of nature), Ibn Asma' said in his narration: It implied an enclosure of the date-trees}}
\hadithdefcmd{muslim}{775}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ - قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ شَرِيكٍ، - يَعْنِي ابْنَ أَبِي نَمِرٍ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، قَالَ خَرَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ الاِثْنَيْنِ إِلَى قُبَاءٍ حَتَّى إِذَا كُنَّا فِي بَنِي سَالِمٍ وَقَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى بَابِ عِتْبَانَ فَصَرَخَ بِهِ فَخَرَجَ يَجُرُّ إِزَارَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْجَلْنَا الرَّجُلَ ‏"‏ ‏.‏ فَقَالَ عِتْبَانُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ الرَّجُلَ يُعْجَلُ عَنِ امْرَأَتِهِ وَلَمْ يُمْنِ مَاذَا عَلَيْهِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا الْمَاءُ مِنَ الْمَاءِ ‏"‏ ‏.‏\hadithno{775}\hadithtrans{Sa'id al-Khudri narrated it from his father:I went to Quba' with the Messenger of Allah (ﷺ) on Monday till we reached (the habitation) of Banu Salim. The Messenger of Allah (ﷺ) stood at the door of 'Itban and called him loudly. So he came out dragging his lower garnment. Upon this the Messenger of Allah (ﷺ) said: We have made this man to make haste 'Itban said: Messenger of Allah, if a man parts with his wife suddenly without seminal emission, what is he required to do (with regard to bath)? The Messenger of Allah (ﷺ) said: It is with the seminal emission that bath becomes obligatory}}
\hadithdefcmd{muslim}{776}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، حَدَّثَهُ أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ حَدَّثَهُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّمَا الْمَاءُ مِنَ الْمَاءِ ‏"‏ ‏.‏\hadithno{776}\hadithtrans{Abu Sa'id al-Khudri reported:The Apostle of Allah (ﷺ) observed: Bathing is obligatory in case of seminal emission}}
\hadithdefcmd{muslim}{777}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا الْمُعْتَمِرُ، حَدَّثَنَا أَبِي، حَدَّثَنَا أَبُو الْعَلاَءِ بْنُ الشِّخِّيرِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْسَخُ حَدِيثُهُ بَعْضُهُ بَعْضًا كَمَا يَنْسَخُ الْقُرْآنُ بَعْضُهُ بَعْضًا ‏.‏\hadithno{777}\hadithtrans{Abu al. 'Ala' b. al-Shikhkhir said:The Messenger of Allah (ﷺ) abrogated some of his commands by others, just as the Qur'an abrogates some part with the other}}
\hadithdefcmd{muslim}{778}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ ذَكْوَانَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ عَلَى رَجُلٍ مِنَ الأَنْصَارِ فَأَرْسَلَ إِلَيْهِ فَخَرَجَ وَرَأْسُهُ يَقْطُرُ فَقَالَ ‏"‏ لَعَلَّنَا أَعْجَلْنَاكَ ‏"‏ ‏.‏ قَالَ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِذَا أُعْجِلْتَ أَوْ أَقْحَطْتَ فَلاَ غُسْلَ عَلَيْكَ وَعَلَيْكَ الْوُضُوءُ ‏"‏ ‏.‏ وَقَالَ ابْنُ بَشَّارٍ ‏"‏ إِذَا أُعْجِلْتَ أَوْ أُقْحِطْتَ ‏"‏ ‏.‏\hadithno{778}\hadithtrans{Abu Sa'id al-Khudri reported:The Messenger of Allah (ﷺ) happened to pass by (the house) of a man amongst the Ansar, and he sent for him. He came out and water was trickling down from his head. Upon this he (the Holy Prophet) said: Perhaps we put you to haste. He said: Yes. Messenger of Allah. He (the Holy Prophet) said: When you made haste or semen is not emitted, bathing is not obligatory for you, but ablution is binding. Ibn Bashshir has narrated it with a minor alteration}}
\hadithdefcmd{muslim}{779}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ أَبِي أَيُّوبَ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الرَّجُلِ يُصِيبُ مِنَ الْمَرْأَةِ ثُمَّ يُكْسِلُ فَقَالَ ‏ "‏ يَغْسِلُ مَا أَصَابَهُ مِنَ الْمَرْأَةِ ثُمَّ يَتَوَضَّأُ وَيُصَلِّي ‏"‏ ‏.‏\hadithno{779}\hadithtrans{Ubayy Ibn Ka'b reported:I arked the Messenger of Allah (ﷺ) about a man who has sexual intercourse with his wife, but leaves her before orgasm. Upon this he (the Holy Prophet) said: He should wash the secretion of his wife, and then perform ablution and ofier prayer}}
\hadithdefcmd{muslim}{780}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، حَدَّثَنِي أَبِي، عَنِ الْمَلِيِّ، عَنِ الْمَلِيِّ، - يَعْنِي بِقَوْلِهِ الْمَلِيِّ عَنِ الْمَلِيِّ أَبُو أَيُّوبَ، - عَنْ أُبَىِّ بْنِ كَعْبٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ فِي الرَّجُلِ يَأْتِي أَهْلَهُ ثُمَّ لاَ يُنْزِلُ قَالَ ‏ "‏ يَغْسِلُ ذَكَرَهُ وَيَتَوَضَّأُ ‏"‏ ‏.‏\hadithno{780}\hadithtrans{Ubayy ibn Ka'b narrated it from the Messenger of Allah (ﷺ) that he said:If a person has sexual intercourse with his wife, but does not experience orgasm, he should wash his organ and perform an ablution}}
\hadithdefcmd{muslim}{781}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، ح وَحَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ، - وَاللَّفْظُ لَهُ - حَدَّثَنِي أَبِي، عَنْ جَدِّي، عَنِ الْحُسَيْنِ بْنِ ذَكْوَانَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ عَطَاءَ بْنَ يَسَارٍ، أَخْبَرَهُ أَنَّ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ أَخْبَرَهُ أَنَّهُ، سَأَلَ عُثْمَانَ بْنَ عَفَّانَ قَالَ قُلْتُ أَرَأَيْتَ إِذَا جَامَعَ الرَّجُلُ امْرَأَتَهُ وَلَمْ يُمْنِ قَالَ عُثْمَانُ ‏ "‏ يَتَوَضَّأُ كَمَا يَتَوَضَّأُ لِلصَّلاَةِ وَيَغْسِلُ ذَكَرَهُ ‏"‏ ‏.‏ قَالَ عُثْمَانُ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{781}\hadithtrans{Zaid b. Khalid al-Jubani reported that he askad Uthman b. 'Affan:What is your opinion about the man who has sexual intercourse with his wife, but does not experience orgasm? Uthman said: He should perform ablution as he does for prayer, and wash his organ. 'Uthmin also said: I have heard it from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{782}{وَحَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، عَنِ الْحُسَيْنِ، قَالَ يَحْيَى وَأَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، أَخْبَرَهُ أَنَّ أَبَا أَيُّوبَ أَخْبَرَهُ أَنَّهُ، سَمِعَ ذَلِكَ، مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{782}\hadithtrans{Abu Ayyub reported that he had heard like this from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{783}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَأَبُو غَسَّانَ الْمِسْمَعِيُّ ح وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالُوا حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، وَمَطَرٍ، عَنِ الْحَسَنِ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا جَلَسَ بَيْنَ شُعَبِهَا الأَرْبَعِ ثُمَّ جَهَدَهَا فَقَدْ وَجَبَ عَلَيْهِ الْغُسْلُ ‏"‏ ‏.‏ وَفِي حَدِيثِ مَطَرٍ ‏"‏ وَإِنْ لَمْ يُنْزِلْ ‏"‏ ‏.‏ قَالَ زُهَيْرٌ مِنْ بَيْنِهِمْ ‏"‏ بَيْنَ أَشْعُبِهَا الأَرْبَعِ ‏"‏ ‏.‏\hadithno{783}\hadithtrans{Abu Huraira reported:The Apostle of Allah (ﷺ) said: When a man has sexual intercourse, bathing becomes obligatory (both for the male and the female). In the hadith of Matar the words are: Even if there is no orgasm. Zuhair has narrated it with a minor alteration of words}}
\hadithdefcmd{muslim}{784}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ عَبَّادِ بْنِ جَبَلَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي وَهْبُ بْنُ جَرِيرٍ، كِلاَهُمَا عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ غَيْرَ أَنَّ فِي حَدِيثِ شُعْبَةَ ‏"‏ ثُمَّ اجْتَهَدَ ‏"‏ وَلَمْ يَقُلْ ‏"‏ وَإِنْ لَمْ يُنْزِلْ ‏"‏ ‏.‏\hadithno{784}\hadithtrans{This hadith is narrated by Qatida with the same chain of transmitters, but with minor alterations. Here instead of the word - (jahada, (ijtahada) has been used, and the words;" Even if there is no orgasm" have been omitted}}
\hadithdefcmd{muslim}{785}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، - وَهَذَا حَدِيثُهُ - حَدَّثَنَا هِشَامٌ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، قَالَ - وَلاَ أَعْلَمُهُ إِلاَّ عَنْ أَبِي بُرْدَةَ، - عَنْ أَبِي مُوسَى، قَالَ اخْتَلَفَ فِي ذَلِكَ رَهْطٌ مِنَ الْمُهَاجِرِينَ وَالأَنْصَارِ فَقَالَ الأَنْصَارِيُّونَ لاَ يَجِبُ الْغُسْلُ إِلاَّ مِنَ الدَّفْقِ أَوْ مِنَ الْمَاءِ ‏.‏ وَقَالَ الْمُهَاجِرُونَ بَلْ إِذَا خَالَطَ فَقَدْ وَجَبَ الْغُسْلُ ‏.‏ قَالَ قَالَ أَبُو مُوسَى فَأَنَا أَشْفِيكُمْ مِنْ ذَلِكَ ‏.‏ فَقُمْتُ فَاسْتَأْذَنْتُ عَلَى عَائِشَةَ فَأُذِنَ لِي فَقُلْتُ لَهَا يَا أُمَّاهْ - أَوْ يَا أُمَّ الْمُؤْمِنِينَ - إِنِّي أُرِيدُ أَنْ أَسْأَلَكِ عَنْ شَىْءٍ وَإِنِّي أَسْتَحْيِيكِ ‏.‏ فَقَالَتْ لاَ تَسْتَحْيِي أَنْ تَسْأَلَنِي عَمَّا كُنْتَ سَائِلاً عَنْهُ أُمَّكَ الَّتِي وَلَدَتْكَ فَإِنَّمَا أَنَا أُمُّكَ ‏.‏ قُلْتُ فَمَا يُوجِبُ الْغُسْلَ قَالَتْ عَلَى الْخَبِيرِ سَقَطْتَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا جَلَسَ بَيْنَ شُعَبِهَا الأَرْبَعِ وَمَسَّ الْخِتَانُ الْخِتَانَ فَقَدْ وَجَبَ الْغُسْلُ ‏"‏ ‏.‏\hadithno{785}\hadithtrans{Abu Musa reported:There cropped up a difference of opinion between a group of Muhajirs (Emigrants and a group of Ansar (Helpers) (and the point of dispute was) that the Ansar said: The bath (because of sexual intercourse) becomes obligatory only-when the semen spurts out or ejaculates. But the Muhajirs said: When a man has sexual intercourse (with the woman), a bath becomes obligatory (no matter whether or not there is seminal emission or ejaculation). Abu Musa said: Well, I satisfy you on this (issue). He (Abu Musa, the narrator) said: I got up (and went) to 'A'isha and sought her permission and it was granted, and I said to her: 0 Mother, or Mother of the Faithful, I want to ask you about a matter on which I feel shy. She said: Don't feel shy of asking me about a thing which you can ask your mother, who gave you birth, for I am too your mother. Upon this I said: What makes a bath obligatory for a person? She replied: You have come across one well informed! The Messenger of Allah (ﷺ) said: When anyone sits amidst four parts (of the woman) and the circumcised parts touch each other a bath becomes obligatory}}
\hadithdefcmd{muslim}{786}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عِيَاضُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ أُمِّ كُلْثُومٍ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ إِنَّ رَجُلاً سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الرَّجُلِ يُجَامِعُ أَهْلَهُ ثُمَّ يُكْسِلُ هَلْ عَلَيْهِمَا الْغُسْلُ وَعَائِشَةُ جَالِسَةٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي لأَفْعَلُ ذَلِكَ أَنَا وَهَذِهِ ثُمَّ نَغْتَسِلُ ‏"‏ ‏.‏\hadithno{786}\hadithtrans{A'isha the wife of the Messenger of Allah (ﷺ) reported. A person asked the Messenger of Allah (ﷺ) about one who has sexual intercourse with his wife and parts away (without orgasm) whether bathing is obligatory for him. 'A'isha was sitting by him. The Messenger of Allah (ﷺ) said:I and she (the Mother of the Faithful) do it and then take a bath}}
\hadithdefcmd{muslim}{787}{وَحَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، قَالَ حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ خَالِدٍ، قَالَ قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي عَبْدُ الْمَلِكِ بْنُ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، أَنَّ خَارِجَةَ بْنَ زَيْدٍ الأَنْصَارِيَّ، أَخْبَرَهُ أَنَّ أَبَاهُ زَيْدَ بْنَ ثَابِتٍ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْوُضُوءُ مِمَّا مَسَّتِ النَّارُ ‏"‏\hadithno{787}\hadithtrans{Zaid b Thabit reported:I heard the Messenger of Allah (ﷺ) say this: Ablution is obligatory (for one who takes anything) touched by fire}}
\hadithdefcmd{muslim}{788}{قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي عُمَرُ بْنُ عَبْدِ الْعَزِيزِ، أَنَّ عَبْدَ اللَّهِ بْنَ إِبْرَاهِيمَ بْنِ قَارِظٍ، أَخْبَرَهُ أَنَّهُ، وَجَدَ أَبَا هُرَيْرَةَ يَتَوَضَّأُ عَلَى الْمَسْجِدِ فَقَالَ إِنَّمَا أَتَوَضَّأُ مِنْ أَثْوَارِ أَقِطٍ أَكَلْتُهَا لأَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تَوَضَّئُوا مِمَّا مَسَّتِ النَّارُ ‏"‏ ‏.‏\hadithno{788}\hadithtrans{Abdullah b. Ibrahim b. Qariz reported that he found Abu Huraira performing ablution in the mosque, who said:I am performing ablution because of having eaten pieces of cheese, for I heard the Messenger of Allah (ﷺ) say: Perform ablution (after eating anything) touched by fire}}
\hadithdefcmd{muslim}{789}{قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي سَعِيدُ بْنُ خَالِدِ بْنِ عَمْرِو بْنِ عُثْمَانَ، وَأَنَا أُحَدِّثُهُ، هَذَا الْحَدِيثَ ‏.‏ أَنَّهُ سَأَلَ عُرْوَةَ بْنَ الزُّبَيْرِ عَنِ الْوُضُوءِ، مِمَّا مَسَّتِ النَّارُ فَقَالَ عُرْوَةُ سَمِعْتُ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَوَضَّئُوا مِمَّا مَسَّتِ النَّارُ ‏"‏ ‏.‏\hadithno{789}\hadithtrans{Urwa reported on the authority of'A'isha, the wife of the Messenger of Allah (ﷺ), saying this:The Messenger of Allah (ﷺ) said. Perform ablution (after eating) anything touched by fire}}
\hadithdefcmd{muslim}{790}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَكَلَ كَتِفَ شَاةٍ ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{790}\hadithtrans{Ibn 'Abbas reported:The Messenger of Allah (ﷺ) took (meat of) goat's shoulder and offered prayer and did not perform ablution}}
\hadithdefcmd{muslim}{791}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَخْبَرَنِي وَهْبُ بْنُ كَيْسَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، ح وَحَدَّثَنِي الزُّهْرِيُّ، عَنْ عَلِيِّ بْنِ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ ابْنِ عَبَّاسٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ عَلِيٍّ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَكَلَ عَرْقًا - أَوْ لَحْمًا - ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ وَلَمْ يَمَسَّ مَاءً ‏.‏\hadithno{791}\hadithtrans{Ibn 'Abbas reported:The Messenger of Allah (ﷺ) took flesh from the bone or meat, and then offered prayer and did not perform ablution, and (in fact) he did not touch water}}
\hadithdefcmd{muslim}{792}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ أُمَيَّةَ الضَّمْرِيِّ، عَنْ أَبِيهِ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يَحْتَزُّ مِنْ كَتِفٍ يَأْكُلُ مِنْهَا ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{792}\hadithtrans{Ja'far b. Amr b. Umayya al-Damari reported on the authority of his father who said:I saw the Messenger of Allah (ﷺ) take slices from goat's shoulder, and then eat them, and then offer prayer without having performed ablution}}
\hadithdefcmd{muslim}{793}{حَدَّثَنِي أَحْمَدُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ أُمَيَّةَ الضَّمْرِيِّ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَحْتَزُّ مِنْ كَتِفِ شَاةٍ فَأَكَلَ مِنْهَا فَدُعِيَ إِلَى الصَّلاَةِ فَقَامَ وَطَرَحَ السِّكِّينَ وَصَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏ قَالَ ابْنُ شِهَابٍ وَحَدَّثَنِي عَلِيُّ بْنُ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ عَنْ أَبِيهِ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِذَلِكَ ‏.‏\hadithno{793}\hadithtrans{Ja'far b. 'Amr b. Umayya al-Damari reported on the authority of his father who said:I saw the Messenger of Allah (ﷺ) take slices from goat's shoulder and then eat them. He was called for prayer and he got'up, leaving aside the knife, and offered prayer but did not perform ablution}}
\hadithdefcmd{muslim}{795}{قَالَ عَمْرٌو وَحَدَّثَنِي بُكَيْرُ بْنُ الأَشَجِّ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ مَيْمُونَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم أَكَلَ عِنْدَهَا كَتِفًا ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{795}\hadithtrans{Ibn 'Abbas reported it on the authority of Maimuana, the wife of the Messenger of Allah (ﷺ), that the Messenger of Allah (ﷺ) took (a piece of goat's) shoulder at her place, and then offered prayer but did not perform ablution}}
\hadithdefcmd{muslim}{796}{قَالَ عَمْرٌو حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ يَعْقُوبَ بْنِ الأَشَجِّ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ مَيْمُونَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم بِذَلِكَ ‏.‏\hadithno{796}\hadithtrans{This hadith has been narrated by Ibn 'Abbas on the authority of Maimuna. the wife of the Apostle (ﷺ), by another chain of transmitters}}
\hadithdefcmd{muslim}{797}{قَالَ عَمْرٌو حَدَّثَنِي سَعِيدُ بْنُ أَبِي هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ أَبِي غَطَفَانَ، عَنْ أَبِي رَافِعٍ، قَالَ أَشْهَدُ لَكُنْتُ أَشْوِي لِرَسُولِ اللَّهِ صلى الله عليه وسلم بَطْنَ الشَّاةِ ثُمَّ صَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{797}\hadithtrans{Abu Rafi' reported:I testify that I used to roast the liver of the goat for the Messenger of Allah (may peace be tipcn him) and then he offered praver but did not perform ablution}}
\hadithdefcmd{muslim}{798}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم شَرِبَ لَبَنًا ثُمَّ دَعَا بِمَاءٍ فَتَمَضْمَضَ وَقَالَ ‏ "‏ إِنَّ لَهُ دَسَمًا ‏"‏ ‏.‏\hadithno{798}\hadithtrans{Ibn Abbas reported:The Apostle (ﷺ) took milk and then called for water and rinsed (his mouth) and said: It contains greasiness}}
\hadithdefcmd{muslim}{799}{وَحَدَّثَنِي أَحْمَدُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ وَهْبٍ، وَأَخْبَرَنِي عَمْرٌو، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ الأَوْزَاعِيِّ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي يُونُسُ، كُلُّهُمْ عَنِ ابْنِ شِهَابٍ، بِإِسْنَادِ عُقَيْلٍ عَنِ الزُّهْرِيِّ، مِثْلَهُ ‏.‏\hadithno{799}\hadithtrans{This hadith has been narrated by another chain of transmitters}}
\hadithdefcmd{muslim}{800}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ حَلْحَلَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَمَعَ عَلَيْهِ ثِيَابَهُ ثُمَّ خَرَجَ إِلَى الصَّلاَةِ فَأُتِيَ بِهَدِيَّةٍ خُبْزٍ وَلَحْمٍ فَأَكَلَ ثَلاَثَ لُقَمٍ ثُمَّ صَلَّى بِالنَّاسِ وَمَا مَسَّ مَاءً ‏.‏\hadithno{800}\hadithtrans{Ibn Abbas reported:The Messenger of Allah (ﷺ) dressed himself, and then went out for prayer, when he was presented with bread and meat. He took three morsels out of that, and then offered prayer along with other people and did not touch water}}
\hadithdefcmd{muslim}{801}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ عَطَاءٍ، قَالَ كُنْتُ مَعَ ابْنِ عَبَّاسٍ ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ ابْنِ حَلْحَلَةَ وَفِيهِ أَنَّ ابْنَ عَبَّاسٍ، شَهِدَ ذَلِكَ مِنَ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَقَالَ صَلَّى وَلَمَ يَقُلْ بِالنَّاسِ ‏.‏\hadithno{801}\hadithtrans{This hadith is narrated by Muhammad b. 'Amr b. Ata' with these words:I was with Ibn 'Abbas, and Ibn 'Abbas saw the Messenger of Allah (ﷺ) doing like this, and it is also said that the words are: He (the Holy Prophet) offered prayer; and the word" people" is not mentioned}}
\hadithdefcmd{muslim}{802}{حَدَّثَنَا أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، عَنْ جَعْفَرِ بْنِ أَبِي ثَوْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَأَتَوَضَّأُ مِنْ لُحُومِ الْغَنَمِ قَالَ ‏"‏ إِنْ شِئْتَ فَتَوَضَّأْ وَإِنْ شِئْتَ فَلاَ تَوَضَّأْ ‏"‏ ‏.‏ قَالَ أَتَوَضَّأُ مِنْ لُحُومِ الإِبِلِ قَالَ ‏"‏ نَعَمْ فَتَوَضَّأْ مِنْ لُحُومِ الإِبِلِ ‏"‏ ‏.‏ قَالَ أُصَلِّي فِي مَرَابِضِ الْغَنَمِ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ أُصَلِّي فِي مَبَارِكِ الإِبِلِ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏\hadithno{802}\hadithtrans{Jabir b. Samura reported:A man asked the Messenger of Allah (may peace he upon him) whether he should perform ablution after (eating) mutton. He (the Messenger of Allah) said: Perform ablution it you so desire, and if you do not wish, do not perform it. He (again) asked: Should I perform ablution (after eating) camel's flesh? He said: Yes, perform ablution (after eating) camel's flesh. He (again) said: May I say prayer in the sheepfolds? He (the Messenger of Allah) said: Yes. He (the narrator) again said: May I say prayer where camels lie down? He (the Holy Prophet) said: No}}
\hadithdefcmd{muslim}{803}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا زَائِدَةُ، عَنْ سِمَاكٍ، ح وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، وَأَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، كُلُّهُمْ عَنْ جَعْفَرِ بْنِ أَبِي ثَوْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ أَبِي كَامِلٍ عَنْ أَبِي عَوَانَةَ ‏.‏\hadithno{803}\hadithtrans{This hadith is also narrated by another chain of transmitters}}
\hadithdefcmd{muslim}{804}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، وَعَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، شُكِيَ إِلَى النَّبِيِّ صلى الله عليه وسلم الرَّجُلُ يُخَيَّلُ إِلَيْهِ أَنَّهُ يَجِدُ الشَّىْءَ فِي الصَّلاَةِ قَالَ ‏ "‏ لاَ يَنْصَرِفُ حَتَّى يَسْمَعَ صَوْتًا أَوْ يَجِدَ رِيحًا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ وَزُهَيْرُ بْنُ حَرْبٍ فِي رِوَايَتِهِمَا هُوَ عَبْدُ اللَّهِ بْنُ زَيْدٍ ‏.‏\hadithno{804}\hadithtrans{Abbad b. Tamim reported from his uncle that a person made a complaint to the Apostle (ﷺ) that he entertained (doubt) as it something had happened to him breaking his ablution. He (the Holy Prophet) said:He should not return (from prayer) unless he hears a sound or perceives a smell (of passing wind). Abu Bakr and Zuhair b. Harb have pointed out in their narrations that it was 'Abdullah b. Zaid}}
\hadithdefcmd{muslim}{805}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وَجَدَ أَحَدُكُمْ فِي بَطْنِهِ شَيْئًا فَأَشْكَلَ عَلَيْهِ أَخَرَجَ مِنْهُ شَىْءٌ أَمْ لاَ فَلاَ يَخْرُجَنَّ مِنَ الْمَسْجِدِ حَتَّى يَسْمَعَ صَوْتًا أَوْ يَجِدَ رِيحًا ‏"‏ ‏.‏\hadithno{805}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: If any one of you has pain in his abdomen, but is doubtful whether or not anything has issued from him, be should not leave the mosque unless he hears a sound or perceives a smell}}
\hadithdefcmd{muslim}{806}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَابْنُ أَبِي عُمَرَ جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، قَالَ يَحْيَى أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ تُصُدِّقَ عَلَى مَوْلاَةٍ لِمَيْمُونَةَ بِشَاةٍ فَمَاتَتْ فَمَرَّ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ هَلاَّ أَخَذْتُمْ إِهَابَهَا فَدَبَغْتُمُوهُ فَانْتَفَعْتُمْ بِهِ ‏"‏ ‏.‏ فَقَالُوا إِنَّهَا مَيْتَةٌ ‏.‏ فَقَالَ ‏"‏ إِنَّمَا حَرُمَ أَكْلُهَا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ وَابْنُ أَبِي عُمَرَ فِي حَدِيثِهِمَا عَنْ مَيْمُونَةَ رضى الله عنها ‏.‏\hadithno{806}\hadithtrans{The freed slave-girl of Maimuna was given a goat in charity but it died. The Messenger of Allah (ﷺ) happened to pass by that (carcass). Upon this be said:Why did you not take off its skin? You could put it to use, after tanning it. They (the Companions) said: It was dead. Upon, this he (the Messenger of Allah) said: Only its eating is prohibited. Abu bakr and Ibn Umar in their narrations said: It is narrated from Maimuna (may Allah be pleased with her)}}
\hadithdefcmd{muslim}{807}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَجَدَ شَاةً مَيْتَةً أُعْطِيَتْهَا مَوْلاَةٌ لِمَيْمُونَةَ مِنَ الصَّدَقَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلاَّ انْتَفَعْتُمْ بِجِلْدِهَا ‏"‏ ‏.‏ قَالُوا إِنَّهَا مَيْتَةٌ ‏.‏ فَقَالَ ‏"‏ إِنَّمَا حَرُمَ أَكْلُهَا ‏"‏ ‏.‏\hadithno{807}\hadithtrans{Ibn 'Abbas said:The Messenger of Allah (ﷺ) saw a dead goat, which had been given in charity to the freed slave-girl of Maimuna. The Messenger of Allah (ﷺ) said: Why don't you make use of its skin? They (the Companions around the Holy Prophet) said: It is dead. Upon this he said: It is the eating (of the dead animal) which is prohibited}}
\hadithdefcmd{muslim}{808}{حَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ بِنَحْوِ رِوَايَةِ يُونُسَ ‏.‏\hadithno{808}\hadithtrans{This hadith is narrated by Ibn Shihab with the same chain of transmitters as transmitted by Yunus}}
\hadithdefcmd{muslim}{809}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَعَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الزُّهْرِيُّ، - وَاللَّفْظُ لاِبْنِ أَبِي عُمَرَ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِشَاةٍ مَطْرُوحَةٍ أُعْطِيَتْهَا مَوْلاَةٌ لِمَيْمُونَةَ مِنَ الصَّدَقَةِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَلاَّ أَخَذُوا إِهَابَهَا فَدَبَغُوهُ فَانْتَفَعُوا بِهِ ‏"‏ ‏.‏\hadithno{809}\hadithtrans{Ibn Abbas reported:The Messenger of Allah (ﷺ) happened to pass by a goat thrown (away) which had been in fact given to the freed slave-girl of Maimuna as charity. Upon this the Messenger of Allah (way peace he upon him) said: Why did they not get its skin? They had better tan it and make use of it}}
\hadithdefcmd{muslim}{810}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَخْبَرَنِي عَطَاءٌ، مُنْذُ حِينٍ قَالَ أَخْبَرَنِي ابْنُ عَبَّاسٍ، أَنَّ مَيْمُونَةَ، أَخْبَرَتْهُ أَنَّ دَاجِنَةً كَانَتْ لِبَعْضِ نِسَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَاتَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَّ أَخَذْتُمْ إِهَابَهَا فَاسْتَمْتَعْتُمْ بِهِ ‏"‏ ‏.‏\hadithno{810}\hadithtrans{Ibn'Abbas reported on the authority of Maimuna that someone amongst the wives of the Messenger of Allah (ﷺ) had a domestic animal and it died. Upon this the Messenger of Allah (ﷺ) said:Why did you not take off its skin and make use of that?}}
\hadithdefcmd{muslim}{811}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِشَاةٍ لِمَوْلاَةٍ لِمَيْمُونَةَ فَقَالَ ‏ "‏ أَلاَّ انْتَفَعْتُمْ بِإِهَابِهَا ‏"‏ ‏.‏\hadithno{811}\hadithtrans{Ibn 'Abbas reported:The Apostle of Allah (ﷺ) happened to pass by (the dead body) of the goat which belonged to the freed slave-girl of Maimuna and said: Why did you not make use of its skin?}}
\hadithdefcmd{muslim}{812}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ وَعْلَةَ، أَخْبَرَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا دُبِغَ الإِهَابُ فَقَدْ طَهُرَ ‏"‏ ‏.‏\hadithno{812}\hadithtrans{Abdullah b. Abbas said:I heard the Messenger of Allah (ﷺ) say: When the skin is tanned it becomes purified}}
\hadithdefcmd{muslim}{813}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، قَالاَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ يَعْنِي ابْنَ مُحَمَّدٍ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ وَكِيعٍ، عَنْ سُفْيَانَ، كُلُّهُمْ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ وَعْلَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ يَعْنِي حَدِيثَ يَحْيَى بْنِ يَحْيَى ‏.‏\hadithno{813}\hadithtrans{This hadith has been transmitted on the authority of Ibn 'Abbas by another chain of transmitters}}
\hadithdefcmd{muslim}{814}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، وَأَبُو بَكْرِ بْنُ إِسْحَاقَ قَالَ أَبُو بَكْرٍ حَدَّثَنَا وَقَالَ ابْنُ مَنْصُورٍ، أَخْبَرَنَا عَمْرُو بْنُ الرَّبِيعِ، أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّ أَبَا الْخَيْرِ، حَدَّثَهُ قَالَ رَأَيْتُ عَلَى ابْنِ وَعْلَةَ السَّبَئِيِّ فَرْوًا فَمَسِسْتُهُ فَقَالَ مَا لَكَ تَمَسُّهُ قَدْ سَأَلْتُ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ قُلْتُ إِنَّا نَكُونُ بِالْمَغْرِبِ وَمَعَنَا الْبَرْبَرُ وَالْمَجُوسُ نُؤْتَى بِالْكَبْشِ قَدْ ذَبَحُوهُ وَنَحْنُ لاَ نَأْكُلُ ذَبَائِحَهُمْ وَيَأْتُونَا بِالسِّقَاءِ يَجْعَلُونَ فِيهِ الْوَدَكَ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ قَدْ سَأَلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ دِبَاغُهُ طَهُورُهُ ‏"‏ ‏.‏\hadithno{814}\hadithtrans{Abu al-Khair reported:I saw Ibn Wa'la al-Saba'i wear a fur. I touched it. He said: Why do you touch it? I asked Ibn 'Abbas saying: We are the inhabitants of the western regions, and there (live) with us Berbers and Magians. They bring with them rams and slaughter them, but we do not eat (the meat of the animals) slaughtered by them, and they come with skins full of fat. Upon this Ibn 'Abbas said: We asked the Messenger of Allah (ﷺ) about this and he said: Its tanning makes it pure}}
\hadithdefcmd{muslim}{815}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، وَأَبُو بَكْرِ بْنُ إِسْحَاقَ عَنْ عَمْرِو بْنِ الرَّبِيعِ، أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ أَبِي الْخَيْرِ، حَدَّثَهُ قَالَ حَدَّثَنِي ابْنُ وَعْلَةَ السَّبَئِيُّ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ قُلْتُ إِنَّا نَكُونُ بِالْمَغْرِبِ فَيَأْتِينَا الْمَجُوسُ بِالأَسْقِيَةِ فِيهَا الْمَاءُ وَالْوَدَكُ فَقَالَ اشْرَبْ ‏.‏ فَقُلْتُ أَرَأْىٌ تَرَاهُ فَقَالَ ابْنُ عَبَّاسٍ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ دِبَاغُهُ طَهُورُهُ ‏"‏ ‏.‏\hadithno{815}\hadithtrans{Ibn Wa'la al-Saba'i reported:I asked 'Abdullah b. 'Abbas saying: We are the inhabitants of the western regions. The Magians come to us with skins full of water and fat. He said: Drink. I said to him: Is it your own opinion? Ibn Abbas said: I heard the Messenger of Allah (ﷺ) say: Tanning purifies it (the skin)}}
\hadithdefcmd{muslim}{816}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ حَتَّى إِذَا كُنَّا بِالْبَيْدَاءِ - أَوْ بِذَاتِ الْجَيْشِ - انْقَطَعَ عِقْدٌ لِي فَأَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْتِمَاسِهِ وَأَقَامَ النَّاسُ مَعَهُ وَلَيْسُوا عَلَى مَاءٍ وَلَيْسَ مَعَهُمْ مَاءٌ فَأَتَى النَّاسُ إِلَى أَبِي بَكْرٍ فَقَالُوا أَلاَ تَرَى إِلَى مَا صَنَعَتْ عَائِشَةُ أَقَامَتْ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَبِالنَّاسِ مَعَهُ وَلَيْسُوا عَلَى مَاءٍ وَلَيْسَ مَعَهُمْ مَاءٌ ‏.‏ فَجَاءَ أَبُو بَكْرٍ وَرَسُولُ اللَّهِ صلى الله عليه وسلم وَاضِعٌ رَأْسَهُ عَلَى فَخِذِي قَدْ نَامَ فَقَالَ حَبَسْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم وَالنَّاسَ وَلَيْسُوا عَلَى مَاءٍ وَلَيْسَ مَعَهُمْ مَاءٌ ‏.‏ قَالَتْ فَعَاتَبَنِي أَبُو بَكْرٍ وَقَالَ مَا شَاءَ اللَّهُ أَنْ يَقُولَ وَجَعَلَ يَطْعُنُ بِيَدِهِ فِي خَاصِرَتِي فَلاَ يَمْنَعُنِي مِنَ التَّحَرُّكِ إِلاَّ مَكَانُ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى فَخِذِي فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَصْبَحَ عَلَى غَيْرِ مَاءٍ فَأَنْزَلَ اللَّهُ آيَةَ التَّيَمُّمِ فَتَيَمَّمُوا ‏.‏ فَقَالَ أُسَيْدُ بْنُ الْحُضَيْرِ - وَهُوَ أَحَدُ النُّقَبَاءِ - مَا هِيَ بِأَوَّلِ بَرَكَتِكُمْ يَا آلَ أَبِي بَكْرٍ ‏.‏ فَقَالَتْ عَائِشَةُ فَبَعَثْنَا الْبَعِيرَ الَّذِي كُنْتُ عَلَيْهِ فَوَجَدْنَا الْعِقْدَ تَحْتَهُ ‏.‏\hadithno{816}\hadithtrans{A'isha reported:We went with the Messenger of Allah (ﷺ) on one of his journeys and when we reached the place Baida' or Dhat al-jaish, my necklace was broken (and fell somewhere). The Messenger of Allah (way peace be upon him) along with other people stayed there for searching it. There was neither any water at that place nor was there any water with them (the Companions of the Holy Prophet). Some persons came to my father Abu Bakr and said: Do you see what 'A'isha has done? She has detained the Messenger of Allah (ﷺ) and persons accompanying him, and there is neither any water here or with them. So Abu Bakr came there and the Messenger of Allah (ﷺ) was sleeping with his head on my thigh. He (Abu Bakr) said: You have detained the Messenger of Allah (ﷺ) and other persons and there is neither water here nor with them. She ('A'isha) said: Abu Bakr scolded me and uttered what Allah wanted him to utter and nudged my hips with his hand. And there was nothing to prevent me from stirring but for the fact that the messenger of Allah (ﷺ) was lying upon my thigh. The Messenger of Allah (ﷺ) slept till it was dawn at a waterless place. So Allah revealed the verses pertaining to tayammum and they (the Prophet and his Companions) performed tayammum. Usaid b. al-Hudair who was one of the leaders said: This is not the first of your blessings,0 Family to Abu Bakr. 'A'isha said: We made the came) stand which was my mount and found the necklace under it}}
\hadithdefcmd{muslim}{817}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، وَابْنُ، بِشْرٍ عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا اسْتَعَارَتْ مِنْ أَسْمَاءَ قِلاَدَةً فَهَلَكَتْ فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَاسًا مِنْ أَصْحَابِهِ فِي طَلَبِهَا فَأَدْرَكَتْهُمُ الصَّلاَةُ فَصَلَّوْا بِغَيْرِ وُضُوءٍ فَلَمَّا أَتَوُا النَّبِيَّ صلى الله عليه وسلم شَكَوْا ذَلِكَ إِلَيْهِ فَنَزَلَتْ آيَةُ التَّيَمُّمِ ‏.‏ فَقَالَ أُسَيْدُ بْنُ حُضَيْرٍ جَزَاكِ اللَّهُ خَيْرًا فَوَاللَّهِ مَا نَزَلَ بِكِ أَمْرٌ قَطُّ إِلاَّ جَعَلَ اللَّهُ لَكِ مِنْهُ مَخْرَجًا وَجَعَلَ لِلْمُسْلِمِينَ فِيهِ بَرَكَةً ‏.‏\hadithno{817}\hadithtrans{A'isha reported she had borrowed from Asma' (her sister) a necklace and it was lost. The Messenger of Allah (ﷺ) sent men to search for it. As it was the time for prayer, they offered prayer without ablution (as water was not available there). When they came to the Messenger of Allah (ﷺ), they made a complaint about it, and the verses pertaining to tayammum were revealed. Upon this Usaid b. Hadair said (to 'A'isha):May Allah grant you a good reward! Never has been there an occasion when you were beset with difficulty and Allah did not make you come out of that and made it an occasion of blessing for the Muslims}}
\hadithdefcmd{muslim}{818}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَابْنُ نُمَيْرٍ جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، قَالَ كُنْتُ جَالِسًا مَعَ عَبْدِ اللَّهِ وَأَبِي مُوسَى فَقَالَ أَبُو مُوسَى يَا أَبَا عَبْدِ الرَّحْمَنِ أَرَأَيْتَ لَوْ أَنَّ رَجُلاً أَجْنَبَ فَلَمْ يَجِدِ الْمَاءَ شَهْرًا كَيْفَ يَصْنَعُ بِالصَّلاَةِ فَقَالَ عَبْدُ اللَّهِ لاَ يَتَيَمَّمُ وَإِنْ لَمْ يَجِدِ الْمَاءَ شَهْرًا ‏.‏ فَقَالَ أَبُو مُوسَى فَكَيْفَ بِهَذِهِ الآيَةِ فِي سُورَةِ الْمَائِدَةِ ‏\{‏ فَلَمْ تَجِدُوا مَاءً فَتَيَمَّمُوا صَعِيدًا طَيِّبًا‏\}‏ فَقَالَ عَبْدُ اللَّهِ لَوْ رُخِّصَ لَهُمْ فِي هَذِهِ الآيَةِ - لأَوْشَكَ إِذَا بَرَدَ عَلَيْهِمُ الْمَاءُ أَنْ يَتَيَمَّمُوا بِالصَّعِيدِ ‏.‏ فَقَالَ أَبُو مُوسَى لِعَبْدِ اللَّهِ أَلَمْ تَسْمَعْ قَوْلَ عَمَّارٍ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَاجَةٍ فَأَجْنَبْتُ فَلَمْ أَجِدِ الْمَاءَ فَتَمَرَّغْتُ فِي الصَّعِيدِ كَمَا تَمَرَّغُ الدَّابَّةُ ثُمَّ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏"‏ إِنَّمَا كَانَ يَكْفِيكَ أَنْ تَقُولَ بِيَدَيْكَ هَكَذَا ‏"‏ ‏.‏ ثُمَّ ضَرَبَ بِيَدَيْهِ الأَرْضَ ضَرْبَةً وَاحِدَةً ثُمَّ مَسَحَ الشِّمَالَ عَلَى الْيَمِينِ وَظَاهِرَ كَفَّيْهِ وَوَجْهَهُ ‏.‏ فَقَالَ عَبْدُ اللَّهِ أَوَلَمْ تَرَ عُمَرَ لَمْ يَقْنَعْ بِقَوْلِ عَمَّارٍ\hadithno{818}\hadithtrans{Shaqiq reported:I was sitting in the company of Abdullah and Abu Musa when Abu Musa said: 0 'Abd al-Rahman (kunya of 'Abdullah b. Mas'ud), what would you like a man to do about the prayer if he experiences a seminal emission or has sexual intercourse but does not find water for a month? 'Abdullah said: He should not perform tayammum even if he does not find water for a month. 'Abdullah said: Then what about the verse in Sura Ma'ida:" If you do not find water, betake yourself to clean dust"? 'Abdullah said: If they were granted concession on the basis of this verse, there is a possibility that they would perform tayammum with dust on finding water very cold for themselves. Abu Musa said to Abdullah: You have not heard the words of 'Ammar: The Messenger of Allah (ﷺ) sent me on an errand and I had a seminal emission, but could find no water, and rolled myself in dust just as a beast rolls itself. I came to the Messenger of Allah (ﷺ) then and made a mention of that to him and he (the Holy Prophet) said: It would have been enough for you to do thus. Then he struck the ground with his hands once and wiped his right hand with the help of his left hand and the exterior of his palms and his face. 'Abdullah said: Didn't you see that Umar was not fully satisfied with the words of 'Ammar only?}}
\hadithdefcmd{muslim}{819}{وَحَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، قَالَ قَالَ أَبُو مُوسَى لِعَبْدِ اللَّهِ وَسَاقَ الْحَدِيثَ بِقِصَّتِهِ نَحْوَ حَدِيثِ أَبِي مُعَاوِيَةَ غَيْرَ أَنَّهُ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا كَانَ يَكْفِيكَ أَنْ تَقُولَ هَكَذَا ‏"‏ ‏.‏ وَضَرَبَ بِيَدَيْهِ إِلَى الأَرْضِ فَنَفَضَ يَدَيْهِ فَمَسَحَ وَجْهَهُ وَكَفَّيْهِ ‏.‏\hadithno{819}\hadithtrans{This hadith is narrated by Shaqiq with the same chain of transmitters but with the alteration of these words:He (the Holy Prophet) struck hands upon the earth, and then shook them and then wiped his face and palm}}
\hadithdefcmd{muslim}{820}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ هَاشِمٍ الْعَبْدِيُّ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ الْقَطَّانَ - عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي الْحَكَمُ، عَنْ ذَرٍّ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَتَى عُمَرَ فَقَالَ إِنِّي أَجْنَبْتُ فَلَمْ أَجِدْ مَاءً ‏.‏ فَقَالَ لاَ تُصَلِّ ‏.‏ فَقَالَ عَمَّارٌ أَمَا تَذْكُرُ يَا أَمِيرَ الْمُؤْمِنِينَ إِذْ أَنَا وَأَنْتَ فِي سَرِيَّةٍ فَأَجْنَبْنَا فَلَمْ نَجِدْ مَاءً فَأَمَّا أَنْتَ فَلَمْ تُصَلِّ وَأَمَّا أَنَا فَتَمَعَّكْتُ فِي التُّرَابِ وَصَلَّيْتُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّمَا كَانَ يَكْفِيكَ أَنْ تَضْرِبَ بِيَدَيْكَ الأَرْضَ ثُمَّ تَنْفُخَ ثُمَّ تَمْسَحَ بِهِمَا وَجْهَكَ وَكَفَّيْكَ ‏"‏ ‏.‏ فَقَالَ عُمَرُ اتَّقِ اللَّهَ يَا عَمَّارُ ‏.‏ قَالَ إِنْ شِئْتَ لَمْ أُحَدِّثْ بِهِ ‏.‏ قَالَ الْحَكَمُ وَحَدَّثَنِيهِ ابْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى عَنْ أَبِيهِ مِثْلَ حَدِيثِ ذَرٍّ قَالَ وَحَدَّثَنِي سَلَمَةُ عَنْ ذَرٍّ فِي هَذَا الإِسْنَادِ الَّذِي ذَكَرَ الْحَكَمُ فَقَالَ عُمَرُ نُوَلِّيكَ مَا تَوَلَّيْتَ ‏.‏\hadithno{820}\hadithtrans{Abd al-Rabmin b. Abza narrated It on the authority of his father that a man came to 'Umar and said:I am (at times) affected by seminal emission but find no water. He ('Umar) told him not to say prayer. 'Ammar then said. Do you remember,0 Commander of the Faithful, when I and you were in a military detachment and we had had a seminal emission and did not find water (for taking bath) and you did not say prayer, but as for myself I rolled in dust and said prayer, and (when it was mentioned before) the Apostle (ﷺ) said: It was enough for you to strike the ground with your hands and then blow (the dust) and then wipe your face and palms. Umar said: 'Ammar, fear Allah. He said: If you so like, I would not narrate it. A hadith like this has been transmitted with the same chain of transmitters but for the words: 'Umar said: We hold you responsible for what you claim}}
\hadithdefcmd{muslim}{821}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، أَخْبَرَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ ذَرًّا، عَنِ ابْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، قَالَ قَالَ الْحَكَمُ وَقَدْ سَمِعْتُهُ مِنِ ابْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَتَى عُمَرَ فَقَالَ إِنِّي أَجْنَبْتُ فَلَمْ أَجِدْ مَاءً ‏.‏ وَسَاقَ الْحَدِيثَ وَزَادَ فِيهِ قَالَ عَمَّارٌ يَا أَمِيرَ الْمُؤْمِنِينَ إِنْ شِئْتَ لِمَا جَعَلَ اللَّهُ عَلَىَّ مِنْ حَقِّكَ لاَ أُحَدِّثُ بِهِ أَحَدًا وَلَمْ يَذْكُرْ حَدَّثَنِي سَلَمَةُ عَنْ ذَرٍّ ‏.‏\hadithno{821}\hadithtrans{Abd al-Rahman b. Abza mnated it on the authority of his father that a man came to Umar and said:I have had a seminal emission but I found no water, and the rest of the hadith is the same but with this addition: 'Amr said: 0 Commander of the Faithful, because of the right given to you by Allah over me, if you desire, I would not narrate this hadith to anyone}}
\hadithdefcmd{muslim}{822}{قَالَ مُسْلِمٌ وَرَوَى اللَّيْثُ بْنُ سَعْدٍ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ عُمَيْرٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّهُ سَمِعَهُ يَقُولُ أَقْبَلْتُ أَنَا وَعَبْدُ الرَّحْمَنِ بْنُ يَسَارٍ، مَوْلَى مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حَتَّى دَخَلْنَا عَلَى أَبِي الْجَهْمِ بْنِ الْحَارِثِ بْنِ الصِّمَّةِ الأَنْصَارِيِّ فَقَالَ أَبُو الْجَهْمِ أَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نَحْوِ بِئْرِ جَمَلٍ فَلَقِيَهُ رَجُلٌ فَسَلَّمَ عَلَيْهِ فَلَمْ يَرُدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَيْهِ حَتَّى أَقْبَلَ عَلَى الْجِدَارِ فَمَسَحَ وَجْهَهُ وَيَدَيْهِ ثُمَّ رَدَّ عَلَيْهِ السَّلاَمَ ‏.‏\hadithno{822}\hadithtrans{Umair, the freed slave of Ibn 'Abbas, reported:I and 'Abd al-Rahmin b. Yasir, the freed slave of Maimuna, the wife of the Apostle (way peace be upon him). came to the house of Abu'l-Jahm b. al-Harith al-Simma Ansari and he said: The Messenger of Allah (ﷺ) came from the direction of Bi'r Jamal and a man met him; he saluted him but the Messenger of Allah (ﷺ) made no response, till he (the Holy Prophet) came to the wall, wiped his face and hands and then returned his salutations}}
\hadithdefcmd{muslim}{823}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، مَرَّ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَبُولُ فَسَلَّمَ فَلَمْ يَرُدَّ عَلَيْهِ ‏.‏\hadithno{823}\hadithtrans{Ibn Umar reported:A person happened to pass by the Messenger of Allah (ﷺ) when he was making water and saluted him, but he did not respond to his salutation}}
\hadithdefcmd{muslim}{824}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - قَالَ حُمَيْدٌ حَدَّثَنَا ح، وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ لَقِيَهُ النَّبِيُّ صلى الله عليه وسلم فِي طَرِيقٍ مِنْ طُرُقِ الْمَدِينَةِ وَهُوَ جُنُبٌ فَانْسَلَّ فَذَهَبَ فَاغْتَسَلَ فَتَفَقَّدَهُ النَّبِيُّ صلى الله عليه وسلم فَلَمَّا جَاءَهُ قَالَ ‏"‏ أَيْنَ كُنْتَ يَا أَبَا هُرَيْرَةَ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ لَقِيتَنِي وَأَنَا جُنُبٌ فَكَرِهْتُ أَنْ أُجَالِسَكَ حَتَّى أَغْتَسِلَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سُبْحَانَ اللَّهِ إِنَّ الْمُؤْمِنَ لاَ يَنْجُسُ ‏"‏ ‏.‏\hadithno{824}\hadithtrans{Abu Huraira reported that he met the Messenger of Allah (ﷺ) on one of the paths leading to Medina in a state of (sexual) defilement and he slipped away and took a bath. The Apostle of Allah (ﷺ) searched for him and when he came, he said to him:0 Abu Huraira, where were you? He said: Messenger of Allah, you met when I was (sexually) defiled and I did not like to sit in your company before taking a bath. Upon this the Messenger of Allah (ﷺ) said: Hallowed be Allah, verily a believer is never defiled}}
\hadithdefcmd{muslim}{825}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ وَاصِلٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَقِيَهُ وَهُوَ جُنُبٌ فَحَادَ عَنْهُ فَاغْتَسَلَ ثُمَّ جَاءَ فَقَالَ كُنْتُ جُنُبًا ‏.‏ قَالَ ‏ "‏ إِنَّ الْمُسْلِمَ لاَ يَنْجُسُ ‏"‏ ‏.‏\hadithno{825}\hadithtrans{Hudhaifa reported:The Messenger of Allah (ﷺ) happened to meet him and he was (sexually) defiled, and he slipped away and took a bath and then came and said: I was (sexually) defiled. Upon this he (the Holy Prophet) remarked: A Muslim is never defiled}}
\hadithdefcmd{muslim}{826}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ وَإِبْرَاهِيمُ بْنُ مُوسَى قَالاَ حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ أَبِيهِ، عَنْ خَالِدِ بْنِ سَلَمَةَ، عَنِ الْبَهِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَذْكُرُ اللَّهَ عَلَى كُلِّ أَحْيَانِهِ ‏.‏\hadithno{826}\hadithtrans{A'isha said:The Apostle of Allah (ﷺ) used to remember Allah at all moments}}
\hadithdefcmd{muslim}{827}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو الرَّبِيعِ الزَّهْرَانِيُّ، قَالَ يَحْيَى أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، وَقَالَ أَبُو الرَّبِيعِ، حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ سَعِيدِ بْنِ الْحُوَيْرِثِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ مِنَ الْخَلاَءِ فَأُتِيَ بِطَعَامٍ فَذَكَرُوا لَهُ الْوُضُوءَ فَقَالَ ‏ "‏ أُرِيدُ أَنْ أُصَلِّيَ فَأَتَوَضَّأَ ‏"‏ ‏.‏\hadithno{827}\hadithtrans{Ibn 'Abbas reported:The Apostle of Allah (ﷺ) came out of the privy, and he was presented with some food, and the people reminded him about ablution, but he said: Am I to say prayer that I should perform ablution?}}
\hadithdefcmd{muslim}{828}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ سَعِيدِ بْنِ الْحُوَيْرِثِ، سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَجَاءَ مِنَ الْغَائِطِ وَأُتِيَ بِطَعَامٍ فَقِيلَ لَهُ أَلاَ تَوَضَّأُ فَقَالَ ‏ "‏ لِمَ أَأُصَلِّي فَأَتَوَضَّأَ ‏"‏ ‏.‏\hadithno{828}\hadithtrans{Ibn 'Abbas reported:We were with the Messenger of Allah (ﷺ) and he had come out of the privy. Food was presented to him. It was said to him (by the Companions around him): Wouldn't you perform ablution? Upon this he said: Why, am I to say prayer that I should perform ablution?}}
\hadithdefcmd{muslim}{829}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا مُحَمَّدُ بْنُ مُسْلِمٍ الطَّائِفِيُّ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ سَعِيدِ بْنِ الْحُوَيْرِثِ، مَوْلَى آلِ السَّائِبِ أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، قَالَ ذَهَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْغَائِطِ فَلَمَّا جَاءَ قُدِّمَ لَهُ طَعَامٌ فَقِيلَ يَا رَسُولَ اللَّهِ أَلاَ تَوَضَّأُ ‏.‏ قَالَ ‏ "‏ لِمَ أَلِلصَّلاَةِ ‏"‏ ‏.‏\hadithno{829}\hadithtrans{Ibn 'Abbas reported:The Messenger of Allah (ﷺ) went to the privy and when he came back, he was presented with food. It was said to him; Messenger of Allah, wouldn't you perform ablution. He said: Why, am I to say prayer?}}
\hadithdefcmd{muslim}{830}{وَحَدَّثَنِي مُحَمَّدُ بْنُ عَمْرِو بْنِ عَبَّادِ بْنِ جَبَلَةَ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ حُوَيْرِثٍ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى حَاجَتَهُ مِنَ الْخَلاَءِ فَقُرِّبَ إِلَيْهِ طَعَامٌ فَأَكَلَ وَلَمْ يَمَسَّ مَاءً ‏.‏ قَالَ وَزَادَنِي عَمْرُو بْنُ دِينَارٍ عَنْ سَعِيدِ بْنِ الْحُوَيْرِثِ أَنَّ النَّبِيَّ صلى الله عليه وسلم قِيلَ لَهُ إِنَّكَ لَمْ تَوَضَّأْ قَالَ ‏ "‏ مَا أَرَدْتُ صَلاَةً فَأَتَوَضَّأَ ‏"‏ ‏.‏ وَزَعَمَ عَمْرٌو أَنَّهُ سَمِعَ مِنْ سَعِيدِ بْنِ الْحُوَيْرِثِ ‏.‏\hadithno{830}\hadithtrans{Ibn Abbas, reported:The Apostle of Allah (ﷺ) came out of the privy after relieving himself, and food was brought to him and he took it, and did not touch water. In another narration transmitted by Sa'id b. al-Huwairith it is like this: It was said to the Messenger of Allah (ﷺ) You have not performed ablution. He said: I do not intend to say prayer that I should perform ablution}}
\hadithdefcmd{muslim}{831}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، وَقَالَ، يَحْيَى أَيْضًا أَخْبَرَنَا هُشَيْمٌ، كِلاَهُمَا عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، - فِي حَدِيثِ حَمَّادٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا دَخَلَ الْخَلاَءَ وَفِي حَدِيثِ هُشَيْمٍ - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا دَخَلَ الْكَنِيفَ قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْخُبْثِ وَالْخَبَائِثِ ‏"‏ ‏.‏\hadithno{831}\hadithtrans{Anas reported:When the Messenger of Allah (ﷺ) entered the privy, and in the hadith transmitted by Hushaim (the words are): When the Messenger of Allah (ﷺ) entered the lavatory, be used to say: O Allah, I seek refuge in Thee from wicked and noxious things}}
\hadithdefcmd{muslim}{832}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ عَبْدِ الْعَزِيزِ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ أَعُوذُ بِاللَّهِ مِنَ الْخُبْثِ وَالْخَبَائِثِ ‏"‏ ‏.‏\hadithno{832}\hadithtrans{This hadith is also transmitted by 'Abd al-'Aziz with the same chain of transmitters, and the words are:I seek refuge with Allah from the wicked and noxious things}}
\hadithdefcmd{muslim}{833}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، ح وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، كِلاَهُمَا عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ أُقِيمَتِ الصَّلاَةُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم نَجِيٌّ لِرَجُلٍ - وَفِي حَدِيثِ عَبْدِ الْوَارِثِ وَنَبِيُّ اللَّهِ صلى الله عليه وسلم يُنَاجِي الرَّجُلَ - فَمَا قَامَ إِلَى الصَّلاَةِ حَتَّى نَامَ الْقَوْمُ ‏.‏\hadithno{833}\hadithtrans{Anas reported:(The people) stood up for prayer and the Messenger of Allah (ﷺ) was whispering to a man, and in the narration of 'Abd al-Warith (the words are): The Apostle of Allah (ﷺ) was having a private conversation with a man, and did not start the prayer till the people dozed off}}
\hadithdefcmd{muslim}{834}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، سَمِعَ أَنَسَ بْنَ مَالِكٍ، قَالَ أُقِيمَتِ الصَّلاَةُ وَالنَّبِيُّ صلى الله عليه وسلم يُنَاجِي رَجُلاً فَلَمْ يَزَلْ يُنَاجِيهِ حَتَّى نَامَ أَصْحَابُهُ ثُمَّ جَاءَ فَصَلَّى بِهِمْ ‏.‏\hadithno{834}\hadithtrans{Anas b. Malik reported:(The people) stood up for prayer and the Messenger of Allah (ﷺ) was talking in whispers with a man, and he did not discontinue the conversation till his Companions dozed off; he then came and led the prayer}}
\hadithdefcmd{muslim}{835}{وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - وَهُوَ ابْنُ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ كَانَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَنَامُونَ ثُمَّ يُصَلُّونَ وَلاَ يَتَوَضَّئُونَ قَالَ قُلْتُ سَمِعْتَهُ مِنْ أَنَسٍ قَالَ إِي وَاللَّهِ ‏.‏\hadithno{835}\hadithtrans{Qatida reported:I heard Anas as saying that the Companion of the Messenger of Allah (ﷺ) dozed off and then offered prayer and did not perform ablution. He (the narrator) said: I asked him if he had actually heard it from Anas. He said: By Allah. yes}}
\hadithdefcmd{muslim}{836}{حَدَّثَنِي أَحْمَدُ بْنُ سَعِيدِ بْنِ صَخْرٍ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّهُ قَالَ أُقِيمَتْ صَلاَةُ الْعِشَاءِ فَقَالَ رَجُلٌ لِي حَاجَةٌ ‏.‏ فَقَامَ النَّبِيُّ صلى الله عليه وسلم يُنَاجِيهِ حَتَّى نَامَ الْقَوْمُ - أَوْ بَعْضُ الْقَوْمِ - ثُمَّ صَلَّوْا ‏.‏\hadithno{836}\hadithtrans{Anas reported:(The people) stood up for the night prayer when a man spoke forth: I need to say something. The Apostle of Allah (ﷺ) entered into secret conversation with him, till the people dozed off or some of the people (dozed off), and then they said the prayer}}
